OC.L10N.register(
    "spreed",
    {
    "a conversation" : "konverzace",
    "(Duration %s)" : "(Doba trvání %s)",
    "You attended a call with {user1}" : "Zúčastnili jste se hovoru s {user1}",
    "_%n guest_::_%n guests_" : ["%n host","%n hosté","%n hostů","%n hosté"],
    "You attended a call with {user1} and {user2}" : "Zúčastnili jste se hovoru s {user1} a {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Zúčastnili jste se hovoru s {user1}, {user2} a {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Zúčastnili jste se hovoru s {user1}, {user2}, {user3} a {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Zúčastnili jste se hovoru s {user1}, {user2}, {user3}, {user4} a {user5}",
    "_%n other_::_%n others_" : ["%n dalším","%n dalšími","%n dalšími","%n dalšími"],
    "{actor} invited you to {call}" : "{actor} vás pozval(a) do {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Byli jste přizvání do <strong>konverzace</strong> nebo vám někdo <strong>volal</strong>",
    "Other activities" : "Ostatní aktivity",
    "Talk" : "Talk",
    "Guest" : "Host",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Vítejte v Nextcloud Talk!\nV této konverzaci budete informováni o nových funkcích, dostupných v Nextcloud Talk.",
    "## New in Talk %s" : "## Novinky v Talk verze %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Účastnit se (video)hovorů je nyní možné i z prohlížečů Microsoft Edge a Safari",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- konverzace se dvěma účastníky jsou nyní trvalé a už se nedají omylem přepnout do skupinové konverzace. Dále, pokud jeden z účastníků odejde, konverzace už není automaticky smazána. Konverzace je ze serveru vymazána teprve, až když odejdou oba",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Nově lze upozornit všechny účastníky chatu a to odesláním „@all“ v příspěvku.",
    "- With the \"arrow-up\" key you can repost your last message" : "- Pomocí šipky nahoru můžete znovu poslat svoji předchozí zprávu.",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk nově disponuje příkazy pro aplikaci. To, zda správce vašeho Nextcloud nějaké nastavil zjistíte posláním zprávy s textem \"/help\"",
    "- With projects you can create quick links between conversations, files and other items" : "- Pomocí projektů lze seskupovat konverzace, soubory a další položky",
    "- You can now mention guests in the chat" : "- Nově lze v konverzacích „zmiňovat“ i hosty.",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Konverzace nyní mohou mít „čekárnu“. To moderátorům umožňuje se k chatu nebo rozhovoru připojit s předstihem a setkání připravit, zatímco ostatní uživatelé a hosté čekají",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Nyní můžete na zprávy odpovídat přímo a poskytnout tak ostatním představu o kontextu vaší zprávy",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Hledání v konverzacích a účastnících nyní také odfiltrovává stávající konverzace, díky čemuž je mnohem snazší najít předchozí konverzace",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Pokud je nainstalovaná aplikace Okruhy, je nyní možné do konverzace přidávat uživatelsky určené skupiny",
    "- Check out the new grid and call view" : "- Podívejte se na nové zobrazení v mřížce a hovoru",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Nyní můžete nahrávat přetažením souborů přímo do chatu",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Sdílené soubory se nyní otevírají přímo v chatu pomocí aplikací pro jejich zobrazení",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Nyní je možné vyhledávat v chatech a zprávách ve sjednoceném vyhledávání v horní liště",
    "- Spice up your messages with emojis from the emoji picker" : "- Okořeňte své zprávy emotikony z dialogu s nimi",
    "- You can now change your camera and microphone while being in a call" : "- Nyní je možné změnit kameru a mikrofon v průběhu hovoru",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Napište popis své konverzace a umožněte ji tak ostatním uživatelům snadněji najít a připojit se",
    "- See a read status and send failed messages again" : "- Zkontrolujte si, kdo si zprávu už přečetl a pošlete ty nedoručené znovu",
    "- Raise your hand in a call with the R key" : "- Přihlaste se při konferenci o slovo stiskem klávesy R",
    "- Join the same conversation and call from multiple devices" : "- Připojit se k té stejné konverzaci a volat z vícero zařízení naráz",
    "- Send voice messages, share your location or contact details" : "- Posílat hlasové zprávy, sdílet svou polohu nebo podrobnosti o kontaktu",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Přidat skupiny do konverzace a jejich noví členové pak budou automaticky přidáni jako účastníci",
    "- A preview of your audio and video is shown before joining a call" : "- Před připojením k hovoru se nyní zobrazuje náhled videa a zvuku od vás",
    "- You can now blur your background in the newly designed call view" : "- V nově navrženém pohledu volání, si za sebou můžete nechat rozmazat pozadí",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderátoři nyní mohou účastníkům upravovat všeobecná a individuální oprávnění",
    "- You can now react to chat messages" : "- Nyní můžete reagovat na zprávy v chatu",
    "- In the sidebar you can now find an overview of the latest shared items" : "- V postranním panelu nyní naleznete přehled naposledy sdílených položek",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Použijte anketu pro shromáždění názorů ostatních nebo pro dohodnutí si data",
    "- Configure an expiration time for chat messages" : "- nastavte dobu skončení platnosti pro zprávy v chatu",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- V konverzacích s mnoha účastníky zahajujte hovory bez upozorňování ostatních. Upozornění na hovory je možné posílat jednotlivě po zahájení hovoru.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Odesílejte zprávy v chatu bez upozorňování příjemců pro případy, že nejsou neodkladné",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emotikony je nyní možné automaticky doplňovat napsáním „:“ (dvojtečky)",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Odkazování na různé položky pomocí nového inteligentního výběru napsáním „/“ (dopředné lomítko)",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Moderátoři nyní mohou vytvářet přestávkové místnosti (vyžaduje podpůrnou vrstvu pro vysoký výkon)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Hovory je nyní možné nahrávat (vyžaduje podpůrnou vrstvu pro vysoký výkon)",
    "- Conversations can now have an avatar or emoji as icon" : "- Konverzace nyní mohou mít jako ikonu avatara či emotikonu",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Ve videohovorech jsou nyní kromě rozmazaného pozadí k dispozici také ta virtuální",
    "- Reactions are now available during calls" : "- V průběhu hovorů jsou nyní k dispozici reakce",
    "- Typing indicators show which users are currently typing a message" : "- Indikátory psaní zobrazují, kteří uživatelé právě píší zprávu",
    "- Groups can now be mentioned in chats" : "- Skupiny je nyní možné zmiňovat v chatech",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Nahrávky hovorů jsou automaticky převáděny na text (pokud je zaregistrována aplikace poskytovatele pro vytváření přepisů)",
    "- Chat messages can be translated if a translation provider app is registered" : "- Zprávy v chatu je možné překládat (pokud je zaregistrována aplikace poskytovatele pro vytváření překladů)",
    "- **Markdown** can now be used in _chat_ messages" : "- ve zprávách v _chatu_ je nyní možné formátovat pomocí **markdown** značek",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- webové háčky jsou nyní k dispozici pro implementaci automatů. Podrobnosti viz dokumentace https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Nastavte si připomínku ohledně zprávy v chatu a buďte tak na ni upozorněni později znovu",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- konverzaci **Poznámky pro mne** použijte pro své poznámky a sdílení informací napříč svými zařízeními",
    "- Captions allow to send a message with a file at the same time" : "- titulky umožňují poslání zprávy se souborem naráz",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- video řečníka je nyní viditelné v průběhu sdílení obrazovky a reakce v hovoru jsou animované",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Zprávy je nyní možné po dobu 6 hodin upravovat přihlášenými autory a moderátory",
    "- Unsent message drafts are now saved in your browser" : "- Neodeslané koncepty zpráv jsou nyní webovým prohlížečem ukládány",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Textové chatování je nyní možné federovaně s ostatními Talk servery",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Moderátoři nyní mohou udělovat účtům vyloučení a hostům bránit v tom, aby se znovu připojovali ke konverzacím",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Nacházející volání z událostí v napojeném kalendáři a zástupy při nepřítomnosti jsou nyní zobrazovány v konverzacích",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Hovory je nyní možné uskutečňovat federovaně s ostatními Talk servery (vyžaduje podpůrnou vrstvu pro vysoký výkon)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Uvádí desktopového klienta Nextcloud Talk pro Windows, macOS a Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Díky Nextcloud asistentovi si nechte vytvářet shrnutí obsahu nahrávek hovorů a nepřečtených zpráv v chat konverzacích",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Vylepšené schůzky s uznávanými hosty pozvanými prostřednictvím jejich e-mailových adres, import seznamů účastníků, koncepty anket a stahování seznamů účastníků hovorů",
    "- Archive conversations to stay focused" : "- Archivujte konverzace a vyhněte se tak rozptylování pozornosti",
    "- Schedule a meeting into your calendar from within a conversation" : "- Naplánujte schůzku ve svém kalendáři přímo z konverzace",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Vyhledávejte ve zprávách stávající konverzace přímo v postranní liště vpravo",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Přehled o více konverzacích naráz pomocí nového zhuštěného seznamu (k zapnutí v nastavení Talk)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- U konverzací v rámci schůzí jsou nyní synchronizovány nadpis a popis z kalendáře a jsou kryté ve vyhledávacím filtru dokud se neblíží svému zahájení",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Označujte v nastavení notifikací konverzace jako citlivé a skrývejte tak obsah zpráv v seznamu konverzací a notifikacích",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Pokud chcete dostávat push notifikace i po dobu „Nevyrušovat“, označte konverzace jako důležité",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Přidávejte ostatní účastníky do hovoru jednoho-s-jedním a vytvářejte tak za pochodu nové skupinové volání",
    "- Use threads to keep your chat and discussions organized" : "– Používejte vlákna a uspořádávejte tak své chaty a diskuze",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- V průběhu hovoru je nyní k dispozici průběžný přepis (vyžaduje ExApp live-transcription a podpůrnou vrstvu pro vysoký výkon)",
    "- Moderators can now pin messages so they are kept at the top" : "- Moderátoři nyní mohou připínat zprávy, takže zůstávají nahoře",
    "- Schedule a message to send it at a later time" : "- Naplánovat zprávu pro její odeslání později",
    "_All %n participant_::_All %n participants_" : ["Všechen %n účastník","Všichni %n účastníci","Všech %n účastníků","Všichni %n účastníci"],
    "Talk updates ✅" : "Aktualizace Talk ✅",
    "Reaction deleted by author" : "Reakce smazána autorem",
    "{actor} created the conversation" : "{actor} vytvořil(a) konverzaci",
    "You created the conversation" : "Vytvořili jste konverzaci",
    "System created the conversation" : "Systém vytvořil konverzaci",
    "An administrator created the conversation" : "Správce vytvořil konverzaci",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} přejmenoval(a) konverzaci z „%1$s“ na „%2$s“",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Přejmenovali jste konverzaci z „%1$s“ na „%2$s“",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Správce přejmenoval konverzaci z „%1$s“ na „%2$s“",
    "{actor} set the description" : "{actor} nastavil(a) popis",
    "You set the description" : "Nastavili jste popis",
    "An administrator set the description" : "Správce nastavil popis",
    "{actor} removed the description" : "{actor} odebral(a) popis",
    "You removed the description" : "Odebrali jste popis",
    "An administrator removed the description" : "Správce odebral popis",
    "You started a silent call" : "Zahájili jste nevyzvánějící hovor",
    "Outgoing silent call" : "Odchozí hovor bez vyzvánění",
    "{actor} started a silent call" : "{actor} zahájil(a) nevyzvánějící hovor",
    "Incoming silent call" : "Příchozí hovor bez vyzvánění",
    "You started a call" : "Zahájili jste hovor",
    "Outgoing call" : "Odchozí hovor",
    "{actor} started a call" : "{actor} zahájil(a) hovor",
    "Incoming call" : "Příchozí hovor",
    "{actor} joined the call" : "{actor} se připojil(a) k hovoru",
    "You joined the call" : "Připojili jste se k hovoru",
    "{actor} left the call" : "{actor} opustil(a) hovor",
    "You left the call" : "Opustili jste hovor",
    "{actor} unlocked the conversation" : "{actor} odemkl(a) konverzaci",
    "You unlocked the conversation" : "Odemkli jste konverzaci",
    "An administrator unlocked the conversation" : "Správce odemknul konverzaci",
    "{actor} locked the conversation" : "{actor} uzamkl(a) konverzaci",
    "You locked the conversation" : "Uzamkli jste konverzaci",
    "An administrator locked the conversation" : "Správce uzamkl konverzaci",
    "{actor} limited the conversation to the current participants" : "{actor} omezil(a) konverzaci pouze na stávající účastníky",
    "You limited the conversation to the current participants" : "Omezili jste konverzaci pouze na stávající účastníky",
    "An administrator limited the conversation to the current participants" : "Správce omezil konverzaci pouze pro stávající účastníky",
    "{actor} opened the conversation to registered users" : "{actor} otevřel(a) konverzaci registrovaným uživatelům",
    "You opened the conversation to registered users" : "Otevřeli jste konverzaci registrovaným uživatelům",
    "An administrator opened the conversation to registered users" : "Správce otevřel konverzaci registrovaným uživatelům",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} otevřel(a) konverzaci registrovaným uživatelům a uživatelům, vytvořeným aplikací Hosté",
    "You opened the conversation to registered users and users created with the Guests app" : "Otevřeli jste konverzaci registrovaným uživatelům a uživatelům, vytvořeným aplikací Hosté",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Správce otevřel konverzaci registrovaným uživatelům a uživatelům, vytvořeným aplikací Hosté",
    "The conversation is now open to everyone" : "Konverzace je nyní otevřena komukoliv",
    "{actor} opened the conversation to everyone" : "{actor} otevřel(a) konverzaci komukoliv",
    "You opened the conversation to everyone" : "Konverzaci jste zpřístupnili komukoliv",
    "{actor} restricted the conversation to moderators" : "{actor} omezil(a) přístup ke konverzaci pouze na moderátory",
    "You restricted the conversation to moderators" : "Omezili jste konverzaci pouze na moderátory",
    "{actor} started breakout rooms" : "{actor} spustil(a) místnosti pro přestávku",
    "You started breakout rooms" : "Spustili jste místnosti pro přestávku",
    "{actor} stopped breakout rooms" : "{actor} zastavil(a) místnosti pro přestávku",
    "You stopped breakout rooms" : "Zastavili jste místnosti pro přestávku",
    "{actor} allowed guests" : "{actor} umožnil(a) hosty",
    "You allowed guests" : "Umožnili jste hosty",
    "An administrator allowed guests" : "Správce povolil hosty",
    "{actor} disallowed guests" : "{actor} nedovolil(a) hosty",
    "You disallowed guests" : "Nedovolili jste hosty",
    "An administrator disallowed guests" : "Správce nepovolil hosty",
    "{actor} set a password" : "{actor} nastavil(a) heslo",
    "You set a password" : "Nastavili jste heslo",
    "An administrator set a password" : "Správce nastavil heslo",
    "{actor} removed the password" : "{actor} odebral(a) heslo",
    "You removed the password" : "Odebrali jste heslo",
    "An administrator removed the password" : "Správce odebral heslo",
    "{actor} added {user}" : "{actor} přidal(a) {user}",
    "You joined the conversation" : "Připojili jste se ke konverzaci",
    "{actor} joined the conversation" : "{actor} se připojil(a) ke konverzaci",
    "You added {user}" : "Přidali jste {user}",
    "{actor} added you" : "{actor} vás přidal(a)",
    "An administrator added you" : "Správce vás přidal",
    "An administrator added {user}" : "Správce přidal {user}",
    "You left the conversation" : "Opustili jste konverzaci",
    "{actor} left the conversation" : "{actor} opustil(a) konverzaci",
    "{actor} removed {user}" : "{actor} odebral(a) {user}",
    "You removed {user}" : "Odebrali jste {user}",
    "{actor} removed you" : "{actor} vás odebral(a)",
    "An administrator removed you" : "Správce vás odebral",
    "An administrator removed {user}" : "Správce odebral {user}",
    "{actor} invited {federated_user}" : "{actor} pozval(a) {federated_user}",
    "You invited {federated_user}" : "Pozvali jste {federated_user}",
    "You accepted the invitation" : "Pozvánku jste přijali",
    "{actor} invited you" : "{actor} vás pozval(a)",
    "An administrator invited you" : "Správce vás pozval",
    "An administrator invited {federated_user}" : "Správce pozval {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} přijal pozvání",
    "{actor} removed {federated_user}" : "{actor} odebral(a) {federated_user}",
    "You removed {federated_user}" : "Odebrali jste {federated_user}",
    "You declined the invitation" : "Odmítli jste pozvánku",
    "An administrator removed {federated_user}" : "Správce odebral {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} odmítl pozvání",
    "{actor} added group {group}" : "{actor} přidal(a) skupinu {group}",
    "You added group {group}" : "Přidali jste skupinu {group}",
    "An administrator added group {group}" : "Správce přidal skupinu {group}",
    "{actor} removed group {group}" : "{actor} odebral(a) skupinu {group}",
    "You removed group {group}" : "Odebrali jste skupinu {group}",
    "An administrator removed group {group}" : "Správce odebral skupinu {group}",
    "{actor} added team {circle}" : "{actor} přidal(a) tým {circle}",
    "You added team {circle}" : "Přidali jste tým {circle}",
    "An administrator added team {circle}" : "Správce přidal tým {circle}",
    "{actor} removed team {circle}" : "{actor} odebral(a) tým {circle}",
    "You removed team {circle}" : "Odebrali jste tým {circle}",
    "An administrator removed team {circle}" : "Správce odebral tým {circle}",
    "{actor} added {phone}" : "{actor} přidal(a) {phone}",
    "You added {phone}" : "Přidali jste {phone}",
    "An administrator added {phone}" : "Správce přidal {phone}",
    "{actor} removed {phone}" : "{actor} odebral(a) {phone}",
    "You removed {phone}" : "Odebrali jste {phone}",
    "An administrator removed {phone}" : "Správce odebral {phone}",
    "{actor} promoted {user} to moderator" : "{actor} povýšil(a) {user} na moderátora",
    "You promoted {user} to moderator" : "Přidali jste {user} práva moderátora",
    "{actor} promoted you to moderator" : "{actor} vás povýšil(a) na moderátora",
    "An administrator promoted you to moderator" : "Správce vás povýšil na moderátora",
    "An administrator promoted {user} to moderator" : "Správce povýšil {user} na moderátora",
    "{actor} demoted {user} from moderator" : "{actor} odebral(a) uživateli {user} oprávnění moderátora",
    "You demoted {user} from moderator" : "Odebrali jste {user} práva moderátora",
    "{actor} demoted you from moderator" : "{actor} vám odebral(a) oprávnění moderátora",
    "An administrator demoted you from moderator" : "Správce vám odebral práva moderátora",
    "An administrator demoted {user} from moderator" : "Správce odebral {user} práva moderátora",
    "{actor} shared a file which is no longer available" : "{actor} nasdílel(a) soubor který už není k dispozici",
    "You shared a file which is no longer available" : "Sdílíte soubor který už není k dispozici",
    "File shares are currently not supported in federated conversations" : "Sdílení souborů prozatím není ve federovaných konverzacích podporováno",
    "The shared location is malformed" : "Popis sdíleného umístění nemá správný formát",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} nastavil(a) Matterbridge pro synchronizaci této konverzace s ostatními chaty",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Nastavili jste Matterbridge pro synchronizaci této konverzace s ostatními chaty",
    "{actor} created thread {title}" : "{actor} vytvořil/a vlákno {title}",
    "You created thread {title}" : "Vytvořili jste vlákno {title}",
    "{actor} renamed thread {title}" : "{actor} přejmenoval/a vlákno {title}",
    "You renamed thread {title}" : "Přejmenovali jste vlákno {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} aktualizoval(a) nastavení pro Matterbridge",
    "You updated the Matterbridge configuration" : "Aktualizovali jste nastavení pro Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} odebral(a) nastavení pro Matterbridge",
    "You removed the Matterbridge configuration" : "Odebrali jste nastavení pro Matterbridge",
    "{actor} started Matterbridge" : "{actor} spustil(a) Matterbridge",
    "You started Matterbridge" : "Spustili jste Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} zastavil(a) Matterbridge",
    "You stopped Matterbridge" : "Zastavili jste Matterbridge",
    "{actor} deleted a message" : "{actor} smazal(a) zprávu",
    "You deleted a message" : "Smazali jste zprávu",
    "{actor} edited a message" : "{actor} upravil(a) zprávu",
    "You edited a message" : "Upravili jste správu",
    "{actor} pinned a message" : "{actor} připnul/a zprávu",
    "You pinned a message" : "Připnuli jste zprávu",
    "{actor} unpinned a message" : "{actor} zrušil/a připnutí zprávy",
    "Message was automatically unpinned" : "Připnutí zprávy bylo automaticky zrušeno",
    "You unpinned a message" : "Zrušili jste připnutí zprávy",
    "{actor} deleted a reaction" : "{actor} smazal(a) reakci",
    "You deleted a reaction" : "Smazali jste reakci",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Nastavili jste omezení platnosti zprávy na %n týden","Nastavili jste omezení platnosti zprávy na %n týdny","Nastavili jste omezení platnosti zprávy na %n týdnů","Nastavili jste omezení platnosti zprávy na %n týdny"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Nastavili jste omezení platnosti zprávy na %n den","Nastavili jste omezení platnosti zprávy na %n dny","Nastavili jste omezení platnosti zprávy na %n dnů","Nastavili jste omezení platnosti zprávy na %n dny"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Nastavili jste omezení platnosti zprávy na %n hodinu","Nastavili jste omezení platnosti zprávy na %n hodiny","Nastavili jste omezení platnosti zprávy na %n hodin","Nastavili jste omezení platnosti zprávy na %n hodiny"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Nastavili jste platnost zprávy na %n minutu","Nastavili jste platnost zprávy na %n minuty","Nastavili jste platnost zprávy na %n minut","Nastavili jste platnost zprávy na %n minuty"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} nastavil(a) omezení platnosti zprávy na %n týden","{actor} nastavil(a) omezení platnosti zprávy na %n týdny","{actor} nastavil(a) omezení platnosti zprávy na %n týdnů","{actor} nastavil(a) omezení platnosti zprávy na %n týdny"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} nastavil(a) omezení platnosti zprávy na %n den","{actor} nastavil(a) omezení platnosti zprávy na %n dny","{actor} nastavil(a) omezení platnosti zprávy na %n dnů","{actor} nastavil(a) omezení platnosti zprávy na %n dny"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} nastavil(a) omezení platnosti zprávy na %n hodinu","{actor} nastavil(a) omezení platnosti zprávy na %n hodiny","{actor} nastavil(a) omezení platnosti zprávy na %n hodin","{actor} nastavil(a) omezení platnosti zprávy na %n hodiny"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} nastavi(a) platnost zprávy na %n minutu","{actor} nastavi(a) platnost zprávy na %n minuty","{actor} nastavi(a) platnost zprávy na %n minut","{actor} nastavi(a) platnost zprávy na %n minuty"],
    "{actor} disabled message expiration" : "{actor} vypnul(a) omezení časové platnosti zprávy",
    "You disabled message expiration" : "Vypnuli jste omezení časové platnosti zprávy",
    "{actor} cleared the history of the conversation" : "{actor} vyčistil(a) historii konverzace",
    "You cleared the history of the conversation" : "Vyčistili jste historii konverzace",
    "{actor} set the conversation picture" : "{actor} nastavil(a) zástupný obrázek",
    "You set the conversation picture" : "Nastavili jste obrázek konverzace",
    "{actor} removed the conversation picture" : "{actor} odebral(a) obrázek konverzace",
    "You removed the conversation picture" : "Odebrali jste obrázek konverzace",
    "{actor} ended the poll {poll}" : "{actor} ukončil(a) anketu {poll}",
    "You ended the poll {poll}" : "Ukončili jste anketu {poll}",
    "{actor} started the video recording" : "{actor} zahájil(a) záznam videa",
    "You started the video recording" : "Zahájili jste záznam videa",
    "{actor} stopped the video recording" : "{actor} ukončil(a) záznam videa",
    "You stopped the video recording" : "Ukončili jste záznam videa",
    "{actor} started the audio recording" : "{actor} zahájil(a) záznam zvuku",
    "You started the audio recording" : "Zahájili jste záznam zvuku",
    "{actor} stopped the audio recording" : "{actor} ukončil(a) záznam zvuku",
    "You stopped the audio recording" : "Zastavili ukončili jste záznam zvuku",
    "The recording failed" : "Nahrávání se nezdařilo",
    "Someone voted on the poll {poll}" : "Někdo hlasoval v anketě {poll}",
    "Message deleted by author" : "Autor zprávu smazal",
    "Message deleted by {actor}" : "Zpráva byla smazána uživatelem {actor}",
    "Message deleted by you" : "Zprávu jste smazali",
    "Deleted user" : "Smazaný uživatel",
    "Unknown number" : "Neznámé číslo",
    "Administration" : "Správa",
    "System" : "Systémové",
    "%s (guest)" : "%s (host)",
    "Missed call" : "Zmeškaný hovor",
    "Unanswered call" : "Nezvednutý hovor",
    "Call ended (Duration {duration})" : "Hovor skončil (trval {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Hovor byl ukončen, protože přesáhl nejvyšší umožněnou délku (trval {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} ukončil(a) hovor (trval {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Hovor s %n hostem byl ukončen, protože přesáhl nejvyšší umožněnou délku (trval {duration})","Hovor se %n hosty byl ukončen, protože přesáhl nejvyšší umožněnou délku (trval {duration})","Hovor s %n hosty byl ukončen, protože přesáhl nejvyšší umožněnou délku (trval {duration})","Hovor se %n hosty byl ukončen, protože přesáhl nejvyšší umožněnou délku (trval {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Hovor s %n hostem skončil (doba trvání {duration})","Hovor se %n hosty skončil (doba trvání {duration})","Hovor se %n hosty skončil (doba trvání {duration})","Hovor se %n hosty skončil (doba trvání {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} ukončil hovor s %n hostem (trval {duration})","{actor} ukončil hovor se %n hosty (trval {duration})","{actor} ukončil hovor s %n hosty (trval {duration})","{actor} ukončil hovor se %n hosty (trval {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Hovor s {user1} byl ukončen, protože přesáhl nejvyšší umožněnou délku (trval {duration})",
    "Call with {user1} ended (Duration {duration})" : "Hovor s {user1} skončil (trval {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} ukončil hovor s {user1} (trval {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Hovor s {user1} a {user2} byl ukončen, protože přesáhl nejvyšší umožněnou délku (trval {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Hovor s {user1} a {user2} skončil (trval {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} ukončil hovor s {user1} a {user2} (trval {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Hovor s {user1}, {user2} a {user3} byl ukončen, protože přesáhl nejvyšší umožněnou délku (trval {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Hovor s {user1}, {user2} a {user3} skončil (trvání {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} ukončil hovor s {user1}, {user2} a {user3} (trval {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Hovor s {user1}, {user2}, {user3} a {user4} byl ukončen, protože přesáhl nejvyšší umožněnou délku (trval {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Hovor s {user1}, {user2}, {user3} a {user4} skončil (trval {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} ukončil hovor s {user1}, {user2}, {user3} a {user4} (trval {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Hovor s {user1}, {user2}, {user3}, {user4} a {user5} byl ukončen, protože přesáhl nejvyšší umožněnou délku (trval {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Hovor s {user1}, {user2}, {user3}, {user4} a {user5} skončil (trval {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} ukončil hovor s {user1}, {user2}, {user3}, {user4} a {user5} (trval {duration})",
    "Message of {user} in {conversation}" : "Zpráva {user} v {conversation}",
    "Message of {user}" : "Zpráva uživatele {user}",
    "Message of a deleted user in {conversation}" : "Zpráva smazaného uživatele v {conversation}",
    "Talk conversations" : "Konverzace v Talk",
    "Talk to %s" : "Talk s %s",
    "An error occurred. Please contact your administrator." : "Došlo k chybě. Obraťte se na svého správce.",
    "Storage quota exceeded" : "Kvóta úložiště překročena",
    "File not found" : "Soubor nenalezen",
    "File is not shared, or shared but not with the user" : "Soubor není sdílen, nebo je sdílený s jiným uživatelem",
    "No account available to delete." : "Není k dispozici žádný účet pro smazání.",
    "Poll" : "Anketa",
    "Password needs to be set" : "Je třeba nastavit heslo",
    "Uploading the file failed" : "Nahrání souboru se nezdařilo",
    "No image file provided" : "Neposkytnut žádný soubor, obsahující obrázek",
    "File is too big" : "Soubor je příliš velký",
    "Invalid file provided" : "Poskytnut neplatný soubor",
    "Invalid image" : "Neplatný obrázek",
    "Unknown filetype" : "Neznámý typ souboru",
    "Talk mentions" : "Zmínění v Talk",
    "More conversations" : "Další konverzace",
    "Say hi to your friends and colleagues!" : "Pozdravte své přátele a kolegy!",
    "No unread mentions" : "Žádná nepřečtená zmínění",
    "Call in progress" : "Probíhá hovor",
    "You were mentioned" : "Byli jste zmíněni",
    "Write to conversation" : "Napsat do konverzace",
    "Writes event information into a conversation of your choice" : "Napíše informace o události do konverzace, kterou zvolíte",
    "Missing email field in header line" : "V řádku hlavičky chybí kolonka e-mail",
    "Following lines are invalid: %s" : "Následující řádky nejsou platné: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s vás přizval/a do konverzace „%2$s“.",
    "You were invited to conversation \"%s\"." : "Jste pozváni do konverzace „%s“.",
    "Conversation invitation" : "Pozvánka do konverzace",
    "Scheduled time" : "Naplánovaný čas",
    "Description" : "Popis",
    "You can also dial-in via phone with the following details" : "Můžete se také připojit voláním z telefonu na následující",
    "Dial-in information" : "Informace o volání sem",
    "Meeting ID" : "Identif. schůzky",
    "Your PIN" : "Váš PIN",
    "Click the button below to join the lobby now." : "Kliknutím na tlačítko níže se k čekárně připojíte nyní.",
    "Click the link below to join the lobby now." : "Kliknutím na odkaz níže se k čekárně připojíte nyní.",
    "Join lobby for \"%s\"" : "Připojit se k čekárně pro „%s“",
    "Click the button below to join the conversation now." : "Kliknutím na tlačítko níže se ke konverzaci připojíte nyní.",
    "Click the link below to join the conversation now." : "Kliknutím na odkaz níže se ke konverzaci připojíte nyní.",
    "Join \"%s\"" : "Připojit se k „%s“",
    "Meeting" : "Schůze",
    "Password request: %s" : "Požadavek na heslo: %s",
    "Private conversation" : "Soukromá konverzace",
    "Deleted user (%s)" : "Smazán uživatel (%s)",
    "Failed to upload call recording" : "Nahrávku se nepodařilo nahrát na server",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Nahrávacímu serveru se nepodařilo nahrát záznam hovoru {call}. Obraťte se na správu.",
    "Share to chat" : "Nasdílet do chatu",
    "Dismiss notification" : "Zahodit upozornění",
    "Call recording now available" : "Nahrávání hovoru je nyní k dispozici",
    "The recording for the call in {call} was uploaded to {file}." : "Nahrávka pro hovor v {call} byla nahrána do {file}.",
    "Transcript now available" : "Přepis je nyní k dispozici",
    "The transcript for the call in {call} was uploaded to {file}." : "Přepis hovoru v {call} byl nahrán do {file}.",
    "Failed to transcript call recording" : "Z nahrávky hovoru se nepodařilo udělat přepis",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Serveru se nepodařilo vytvořit přepis nahrávky v {file} pro hovor v {call}. Obraťte se na správu.",
    "Call summary now available" : "Souhrn hovoru je nyní k dispozici",
    "The summary for the call in {call} was uploaded to {file}." : "Shrnutí hovoru v {call} bylo nahráno do {file}.",
    "Failed to summarize call recording" : "Nepodařilo se shrnout nahrávku hovoru",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Serveru se nepodařilo shrnout obsah nahrávky v {file} pro hovor v {call}. Obraťte se na správu.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} vás pozval(a) do {roomName} na {remoteServer}",
    "Accept" : "Přijmout",
    "Decline" : "Odmítnout",
    "{user1} invited you to a federated conversation" : "{user} vás pozval(a) do federované konverzace",
    "Someone reacted" : "Někdo zareagoval",
    "New message" : "Nová zpráva",
    "Reminder" : "Připomínka",
    "Someone mentioned you" : "Někdo vás zmínil",
    "Notification" : "Upozornění",
    "Someone reacted in a private conversation" : "Někdo reagoval v soukromé konverzaci",
    "You received a message in a private conversation" : "Obdrželi jste zprávu v soukromé konverzaci",
    "Reminder in a private conversation" : "Připomínka v soukromé konverzaci",
    "Someone mentioned you in a private conversation" : "Někdo vás zmínil v soukromé konverzaci",
    "Notification in a private conversation" : "Upozornění v soukromé konverzaci",
    "Reminder: You in {call}" : "Připomínka: Vy v {call}",
    "Reminder: {user} in {call}" : "Připomínka: {user} v {call}",
    "Reminder: Deleted user in {call}" : "Připomínka: smazaný uživatel v {call}",
    "Reminder: {guest} (guest) in {call}" : "Připomínka: {guest} (guest) v {call}",
    "Reminder: Guest in {call}" : "Připomínka: host v {call}",
    "{user} reacted with {reaction}" : "{user} reagoval(a) s {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} reagoval(a) s {reaction} v {call}",
    "Deleted user reacted with {reaction} in {call}" : "Smazaný uživatel reagoval {reaction} v {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (host) reagoval(a) {reaction} v {call}",
    "Guest reacted with {reaction} in {call}" : "Host reagoval {reaction} v {call}",
    "{user} in {call}" : "{user} v {call}",
    "Deleted user in {call}" : "Smazaný uživatel v {call}",
    "{guest} (guest) in {call}" : "{guest} (host) v {call}",
    "Guest in {call}" : "Host v {call}",
    "{user} sent you a private message" : "{user} vám poslal(a) soukromou zprávu",
    "{user} sent a message in conversation {call}" : "{user} poslal(a) zprávu v konverzaci {call}",
    "A deleted user sent a message in conversation {call}" : "Smazaný uživatel poslal zprávu v konverzaci {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (host) poslal(a) zprávu v konverzaci {call}",
    "A guest sent a message in conversation {call}" : "Host poslal zprávu v konverzaci {call}",
    "{user} replied to your private message" : "{user} odpověděl(a) na vaši soukromou zprávu",
    "{user} replied to your message in conversation {call}" : "{user} odpověděl(a) na vaši zprávu v konverzaci {call}",
    "A deleted user replied to your message in conversation {call}" : "Smazaný/á uživatel(ka) odpověděl(a) na vaši zprávu v konverzaci {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (host) odpověděl(a) na vaši zprávu v konverzaci {call}",
    "A guest replied to your message in conversation {call}" : "Host odpověděl(a) na vaši zprávu v konverzaci {call}",
    "Reminder: You in private conversation {call}" : "Připomínka: Vy v soukromé konverzaci {call}",
    "Reminder: A deleted user in private conversation {call}" : "Připomínka:  smazaný uživatel v soukromé konverzaci {call}",
    "Reminder: {user} in private conversation" : "Připomínka:  {user} v soukromé konverzaci",
    "Reminder: You in conversation {call}" : "Připomínka: Vy v konverzaci {call}",
    "Reminder: {user} in conversation {call}" : "Připomínka: {user} v konverzaci {call}",
    "Reminder: A deleted user in conversation {call}" : "Připomínka:  smazaný uživatel v konverzaci {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Připomínka: {guest} (host) v konverzaci {call}",
    "Reminder: A guest in conversation {call}" : "Připomínka: host v konverzaci {call}",
    "{user} reacted with {reaction} to your private message" : "{user} zareagoval(a) s {reaction} na vaši soukromou zprávu",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} zareagoval(a) s {reaction} na vaši zprávu v konverzaci {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Smazaný uživatel zareagoval s {reaction} na vaši zprávu v konverzaci {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (host) zareagoval(a) s {reaction} na vaši zprávu v konverzaci {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Host zareagoval(a) s {reaction} na vaši zprávu v konverzaci {call}",
    "{user} mentioned you in a private conversation" : "{user} vás zmínil(a) v soukromé konverzaci",
    "{user} mentioned group {group} in conversation {call}" : "{user} zmínil(a) skupinu {group} v konverzaci {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} zmínil(a) tým {team} v konverzaci {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} zmínil(a) všechny v konverzaci {call}",
    "{user} mentioned you in conversation {call}" : "{user} vás zmínil(a) v konverzaci {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Smazaný uživatel zmínil skupinu {group} v konverzaci {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Smazaný uživatel zmínil tým {team} v konverzaci {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Smazaný uživatel zmínil všechny v konverzaci {call}",
    "A deleted user mentioned you in conversation {call}" : "Smazaný uživatel vás zmínil v konverzaci {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{host} (host) zmínil(a) skupinu {group} v konverzaci {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (host) zmínil(a) tým {team} v konverzaci {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{host} (host) zmínil(a) všechny v konverzaci {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (host) vás zmínil(a) v konverzaci {call}",
    "A guest mentioned group {group} in conversation {call}" : "Host zmínil skupinu {group} v konverzaci {call}",
    "A guest mentioned team {team} in conversation {call}" : "Host zmínil tým {team} v konverzaci {call}",
    "A guest mentioned everyone in conversation {call}" : "Host zmínil všechny v konverzaci {call}",
    "A guest mentioned you in conversation {call}" : "Host vás zmínil v konverzaci {call}",
    "View message" : "Zobrazit zprávu",
    "Dismiss reminder" : "Zahodit připomínku",
    "View chat" : "Zobrazit chat",
    "{user} invited you to a group conversation: {call}" : "{user} vás pozval(a) do skupinové konverzace: {call}",
    "Join call" : "Připojit se k hovoru",
    "Answer call" : "Přijmout hovor",
    "{user} would like to talk with you" : "{user} si s vámi přeje mluvit",
    "Call back" : "Zavolat zpátky",
    "You missed a call from {user}" : "Zmeškali jste hovor od {user}",
    "Accept call" : "Přijmout vše",
    "Incoming phone call from {call}" : "Příchozí hovor od {call}",
    "You missed a phone call from {call}" : "Zmeškali jste hovor od {call}",
    "A group call has started in {call}" : "V {call} byl zahájen skupinový hovor",
    "You missed a group call in {call}" : "Zmeškali jste skupinový hovor v {call}",
    "{email} is requesting the password to access {file}" : "{email} požádal(a) o heslo pro přístup k {file}",
    "{email} tried to request the password to access {file}" : "{email} se pokusil(a) vyžádat si heslo pro přístup k {file}",
    "Someone is requesting the password to access {file}" : "Někdo si žádá o heslo pro přístup k {file}",
    "Someone tried to request the password to access {file}" : "Někdo se pokusil(a) vyžádat si heslo pro přístup k {file}",
    "Open settings" : "Otevřít nastavení",
    "Hosted signaling server added" : "Hostovaný signální server přidán",
    "The hosted signaling server is now configured and will be used." : "Nyní je nastavený hostovaný signalizační server a bude použit.",
    "Hosted signaling server removed" : "Hostovaný signální server odebrán",
    "The hosted signaling server was removed and will not be used anymore." : "Hostovaný signální server byl odebrán a už nebude používán.",
    "Hosted signaling server changed" : "Hostovaný signální server změněn",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Stav účtu na hostovaném signalizačním serveru se změnil z „{oldstatus}“ na „{newstatus}“.",
    "pending" : "čeká",
    "active" : "aktivní",
    "expired" : "platnost skončila",
    "blocked" : "blokováno",
    "error" : "chyba",
    "The certificate of {host} expires in {days} days" : "Certifikátu {host} skončí platnost za {days} dny/ů",
    "The certificate of {host} expired" : "Platnost certifikátu {host} skončila",
    "Contact via Talk" : "Kontakt přes Talk",
    "Open Talk" : "Otevřít Talk",
    "Default" : "Výchozí",
    "Presentation" : "Prezentace",
    "Voice room" : "Hlasová místnost",
    "Webinar" : "Webinář",
    "Conversations" : "Konverzace",
    "Messages in current conversation" : "Zprávy ve stávající konverzaci",
    "{user}" : "{user}",
    "Messages" : "Zprávy",
    "{user} in {conversation}" : "{user} v {conversation}",
    "Messages in other conversations" : "Zprávy v ostatních konverzacích",
    "One-to-one rooms always need to show the other users avatar" : "Místnosti typu s jen dvěma komunikujícími vždy vyžadují zobrazení profilového obrázku druhého uživatele",
    "Invalid emoji character" : "Neplatný znak emotikony",
    "Invalid background color" : "Neplatná barva pozadí",
    "Avatar image is not square" : "Profilový obrázek není čtvercový",
    "Room {number}" : "Místnost {number}",
    "Other" : "Ostatní",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Nepodařilo se zažádat o zkušební období, protože příslušný server není dosažitelný. Prosím zkuste to znovu později.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Je problém s ověřováním této instance. Možná není dosažitelná zvenčí, což je třeba pro ověření její URL adresy.",
    "Something unexpected happened." : "Stalo se něco neočekávaného.",
    "The URL is invalid." : "URL adresa není platná.",
    "An HTTPS URL is required." : "Je zapotřebí HTTPS URL.",
    "The email address is invalid." : "E-mailová adresa není platná.",
    "The language is invalid." : "Jazyk není platný.",
    "The country is invalid." : "Země není platná.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Je problém se žádostí o zkušební období. Podrobnosti naleznete v záznamech událostí.",
    "Too many requests are send from your servers address. Please try again later." : "Z adresy vašeho serveru bylo odesláno příliš mnoho požadavků. Prosím zkuste to znovu později.",
    "There is already a trial registered for this Nextcloud instance." : "Pro tuto instanci Nextcloud už je zaregistrováno zkušební období.",
    "Something unexpected happened. Please try again later." : "Stalo se něco neočekávaného. Prosím zkuste to znovu později.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Nepodařilo se zažádat o zkušební období, protože příslušný server se zachoval chybně. Prosím zkuste to znovu později.",
    "Trial requested but failed to get account information. Please check back later." : "O zkušební období zažádáno, ale nepodařilo se získat informace o účtu. Prosím vraťte se sem později.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Je problém s ověřením tohoto požadavku. Možné není dosažitelné zvenčí, což je třeba pro ověření jeho URL adresy.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Nepodařilo se získat informace o účtu, protože server pro vyzkoušení si se zachoval chybně. Prosím vraťte se sem později.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Je problém se získáním informací o účtu. Další informace naleznete v záznamech událostí.",
    "There is no such account registered." : "Není zde zaregistrován žádný takový účet.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Nepodařilo se získat informace o účtu, protože server pro vyzkoušení si není dosažitelný. Prosím vraťte se sem později.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Smazání účtu hostovaného signalizačního serveru se nezdařilo. Prosím vraťte se sem později.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Účet se nepodařilo smazat protože server pro vyzkoušení si se zachoval chybně. Prosím vraťte se sem později.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Je problém se smazáním účtu. Další informace naleznete v záznamech událostí.",
    "Too many requests are sent from your servers address. Please try again later." : "Z adresy vašeho serveru bylo odesláno příliš mnoho požadavků. Prosím zkuste to znovu později.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Účet se nepodařilo smazat, protože server pro vyzkoušení si není dosažitelný. Prosím vraťte se sem znovu později.",
    "Note to self" : "Poznámka pro mne",
    "A place for your private notes, thoughts and ideas" : "Místo pro vaše soukromé poznámky, myšlenky a nápady",
    "Transcript is AI generated and may contain mistakes" : "Přepis je vytvářen AI a může obsahovat chyby",
    "Summary is AI generated and may contain mistakes" : "Shrnutí je vytvářeno AI a může obsahovat chyby",
    "Let's get started!" : "Začněme!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** je bezpečná komunikační platforma, která je plně integrovaná do ekosystému Nextcloud.\n\n#### Klíčové vymoženosti Nextcloud Talk:\n\n* Chatování v místnostech jeden na jednoho i ve skupinových chatech\n* Umožňuje uskutečňovat hlasové hovory i video hovory \n* Můžete jednoduše posílat soubory a využívat integrace s dalšími aplikacemi Nextcloud\n* Nabízí možnosti přizpůsobení konverzací, jejich moderování a správu soukromí\n* Je možné ho používat na Webu, počítači i mobilu (s operačním systémem iOS nebo Android)\n* Skutečně soukromou a zabezpečenou komunikaci\n\nZjistěte více v [dokumentaci pro uživatele](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Vítejte v Nextcloud Talk\n\nNextcloud Talk je soukromá a vybavená aplikace pro posílání zpráv, napojená na Nextcloud server. Pište si v soukromých nebo skupinových konverzacích, spolupracujte prostřednictvím hlasových a video hovorů, uspořádávejte webináře a události, přizpůsobujte si své konverzace a mnoho dalšího.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Využívejte možností formátování a vytvářejte líbivé zprávy\n\nV Nextcloud Talk můžete pro formátování zpráv využívat syntaxu Markdown. Například můžete text **ztučnit**, napsat ho *kurzívou* nebo `ho zvýrazňovat jako programový kód`. Dokonce můžete vytvářet tabulky, nadpisy a záhlaví.\n\nPotřebujete opravit překlep nebo změnit formátování? Upravte zprávu ťuknutím na tlačítko \"Upravit zprávu\" v podmenu zprávy.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Vkládejte přílohy a odkazy\n\nPřipojujte soubory z Nextcloud Hubu pomocí tlačítka \"+\". Sdílejte soubory a položky z dalších aplikací Nextcloud. Některé aplikace podporují i interaktivní widgety, například aplikace Text.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Nechte rozhovory téct proudem: zmiňujte uživatele a reagujte na zprávy\n\nMůžete zmínit všechny účastníky konverzace použitím %s - anebo zmiňte jen specifické osoby tak, že napíšete \"@\" a jejich jméno dopíšete nebo ho vyberete ze seznamu.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Na zprávy je možné odpovídat, přeposílat je do dalších chatů nebo kopírovat jejich obsah.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Buďte rychlejší se Smart Picker\n\nJen napište \"/\" nebo běžte do nabídky \"+\" odkud otevřete Smart Picker díky kterému můžete ke svým zprávám přikládat nepřeberné množství obsahu. Smart Picker také můžete nakonfigurovat tak, aby byl schopný připojovat položky z aplikací Nextcloud, GIFy, umístění na mapách, obsah vygenerovaný AI a mnoho dalšího.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Spravujte nastavení konverzací\n\nV menu konverzace můžete přistupovat k mnoha nastavením, pomocí kterých můžete chaty spravovat, například můžete:\n* Upravovat informace o konverzaci a její popis\n* Spravovat oznámení\n* Vynucovat moderační pravidla\n* Spravovat přístup a zabezpečení\n* Přidávat roboty\n* a je tam toho ještě víc!",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Spojené Arabské Emiráty",
    "Afghanistan" : "Afgánistán",
    "Antigua and Barbuda" : "Antigua a Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albánie",
    "Armenia" : "Arménie",
    "Angola" : "Angola",
    "Antarctica" : "Antarktida",
    "Argentina" : "Argentina",
    "American Samoa" : "Americká Samoa",
    "Austria" : "Rakousko",
    "Australia" : "Austrálie",
    "Aruba" : "Aruba",
    "Åland Islands" : "Alandy",
    "Azerbaijan" : "Ázerbájdžán",
    "Bosnia and Herzegovina" : "Bosna a Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladéš",
    "Belgium" : "Belgie",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulharsko",
    "Bahrain" : "Bahrajn",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Svatý Bartoloměj",
    "Bermuda" : "Bermudy",
    "Brunei Darussalam" : "Brunej",
    "Bolivia, Plurinational State of" : "Bolívie",
    "Bonaire, Sint Eustatius and Saba" : "Karibské Nizozemsko",
    "Brazil" : "Brazílie",
    "Bahamas" : "Bahamy",
    "Bhutan" : "Bhútán",
    "Bouvet Island" : "Bouvetův ostrov",
    "Botswana" : "Botswana",
    "Belarus" : "Bělorusko",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosové ostrovy",
    "Congo, the Democratic Republic of the" : "Kongo",
    "Central African Republic" : "Středoafrická republika",
    "Congo" : "Kongo",
    "Switzerland" : "Švýcarsko",
    "Côte d'Ivoire" : "Pobřeží slonoviny",
    "Cook Islands" : "Cookovy ostrovy",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Čína",
    "Colombia" : "Kolumbie",
    "Costa Rica" : "Kostarika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kapverdy",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Vánoční ostrov",
    "Cyprus" : "Kypr",
    "Czechia" : "Česko",
    "Germany" : "Německo",
    "Djibouti" : "Džibutsko",
    "Denmark" : "Dánsko",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikánská republika",
    "Algeria" : "Alžír",
    "Ecuador" : "Ekvádor",
    "Estonia" : "Estonsko",
    "Egypt" : "Egypt",
    "Western Sahara" : "Západní Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Španělsko",
    "Ethiopia" : "Etiopie",
    "Finland" : "Finsko",
    "Fiji" : "Fidži",
    "Falkland Islands (Malvinas)" : "Falklandské ostrovy (Malvíny)",
    "Micronesia, Federated States of" : "Mikronésie",
    "Faroe Islands" : "Faerské ostrovy",
    "France" : "Francie",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Spojené království Velké Británie a Severního Irska",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzie",
    "French Guiana" : "Francouzská Guyana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grónsko",
    "Gambia" : "Gambie",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Rovníková Guinea",
    "Greece" : "Řecko",
    "South Georgia and the South Sandwich Islands" : "Jižní Georgie a Jižní Sandwichovy ostrovy",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hongkong",
    "Heard Island and McDonald Islands" : "Heardův ostrov a McDonaldovy ostrovy",
    "Honduras" : "Honduras",
    "Croatia" : "Chorvatsko",
    "Haiti" : "Haiti",
    "Hungary" : "Maďarsko",
    "Indonesia" : "Indonézie",
    "Ireland" : "Irsko",
    "Israel" : "Izrael",
    "Isle of Man" : "Man",
    "India" : "Indie",
    "British Indian Ocean Territory" : "Britské indickooceánské území",
    "Iraq" : "Irák",
    "Iran, Islamic Republic of" : "Írán",
    "Iceland" : "Island",
    "Italy" : "Itálie",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordánsko",
    "Japan" : "Japonsko",
    "Kenya" : "Keňa",
    "Kyrgyzstan" : "Kyrgyzstán",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komory",
    "Saint Kitts and Nevis" : "Svatý Kryštof a Nevis",
    "Korea, Democratic People's Republic of" : "Severní Korea (KLDR)",
    "Korea, Republic of" : "Jižní Korea",
    "Kuwait" : "Kuvajt",
    "Cayman Islands" : "Kajmanské ostrovy",
    "Kazakhstan" : "Kazachstán",
    "Lao People's Democratic Republic" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Svatá Lucie",
    "Liechtenstein" : "Lichnštejnsko",
    "Sri Lanka" : "Srí Lanka",
    "Liberia" : "Libérie",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litva",
    "Luxembourg" : "Lucembursko",
    "Latvia" : "Lotyšsko",
    "Libya" : "Libye",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova, Republic of" : "Moldávie",
    "Montenegro" : "Černá Hora",
    "Saint Martin (French part)" : "Svatý Martin (francouzská část)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Maršalovy ostrovy",
    "North Macedonia" : "Severní Makedonie",
    "Mali" : "Mali",
    "Myanmar" : "Barma",
    "Mongolia" : "Mongolsko",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Severní Mariany",
    "Martinique" : "Martinik",
    "Mauritania" : "Mauritánie",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurícius",
    "Maldives" : "Maledivy",
    "Malawi" : "Malawi",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malajsie",
    "Mozambique" : "Mozambik",
    "Namibia" : "Nambie",
    "New Caledonia" : "Nová Kaledonie",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk",
    "Nigeria" : "Nigérie",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Nizozemí",
    "Norway" : "Norsko",
    "Nepal" : "Nepál",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nový Zéland",
    "Oman" : "Omán",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Francouzská Polynésie",
    "Papua New Guinea" : "Papua-Nová Guinea",
    "Philippines" : "Filipíny",
    "Pakistan" : "Pakistán",
    "Poland" : "Polsko",
    "Saint Pierre and Miquelon" : "Saint-Pierre a Miquelon",
    "Pitcairn" : "Pitcairnovy ostrovy",
    "Puerto Rico" : "Portoriko",
    "Palestine, State of" : "Palestina",
    "Portugal" : "Portugalsko",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Rumunsko",
    "Serbia" : "Srbsko",
    "Russian Federation" : "Ruská federace",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudská Arábie",
    "Solomon Islands" : "Šalamounovy ostrovy",
    "Seychelles" : "Seychely",
    "Sudan" : "Súdán",
    "Sweden" : "Švédsko",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Svatá Helena",
    "Slovenia" : "Slovinsko",
    "Svalbard and Jan Mayen" : "Špicberky a Jan Mayen",
    "Slovakia" : "Slovensko",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somálsko",
    "Suriname" : "Surinam",
    "South Sudan" : "Jižní Súdán",
    "Sao Tome and Principe" : "Svatý Tomáš a Princův ostrov",
    "El Salvador" : "Salvador",
    "Sint Maarten (Dutch part)" : "Svatý Martin (nizozemská část)",
    "Syrian Arab Republic" : "Sýrie",
    "Eswatini" : "Svazijsko",
    "Turks and Caicos Islands" : "Turks a Caicos",
    "Chad" : "Čad",
    "French Southern Territories" : "Francouzská jižní a antarktická území",
    "Togo" : "Togo",
    "Thailand" : "Thajsko",
    "Tajikistan" : "Tádžikistán",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Východní Timor",
    "Turkmenistan" : "Turkmenistán",
    "Tunisia" : "Tunisko",
    "Tonga" : "Tonga",
    "Turkey" : "Turecko",
    "Trinidad and Tobago" : "Trinidad a Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Tchaj-wan (provincie)",
    "Tanzania, United Republic of" : "Tanzanie",
    "Ukraine" : "Ukrajina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Menší odlehlé ostrovy Spojených států amerických",
    "United States of America" : "Spojené státy americké",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistán",
    "Holy See" : "Svatý stolec",
    "Saint Vincent and the Grenadines" : "Svatý Vincenc a Grenadiny",
    "Venezuela, Bolivarian Republic of" : "Venezuela",
    "Virgin Islands, British" : "Britské Panenské ostrovy",
    "Virgin Islands, U.S." : "Americké Panenské ostrovy",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis a Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Jihoafrická republika",
    "Zambia" : "Zambie",
    "Zimbabwe" : "Zimbabwe",
    "Background blur" : "Rozmazání pozadí",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Nepodařilo se zkontrolovat podporu načítání WASM. Zkontrolujte ručně, zda vámi využívaný webový server poskytuje .wasm` soubory.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Váš webový server není správně nastaven k doručování `.wasm` souborů. To je obvykle chyba v nastavení Nginx. Pro rozmazávání pozadí potřebuje úpravu také k doručování `.wasm` souborů. Porovnejte své nastavení Nginx s doporučeným nastavením v naší dokumentaci.",
    "Talk configuration values" : "Hodnoty nastavení Talk",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Vynucování omezení délky hovoru je podporováno pouze při používání systémového plánovače cron. Zapněte jeho používání nebo odeberte nastavení `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Nízké hodnoty `max_call_duration` (nyní nastaveno na %d) nejsou vynutitelné z důvodu technických omezení. Úloha na pozadí je spouštěna pouze co 5 minut, takže použijte na své vlastní riziko.",
    "Federation" : "Federování",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Pokud je zapnuté federování v Talk, je vřele doporučováno nastavit „memcache.locking“.",
    "High-performance backend" : "Podpůrná vrstva pro vysoký výkon",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Není nastavená žádná podpůrná vrstva pro vysoký výkon. Provozování Nextcloud Talk bez ní škáluje pouze pro velmi malé hovory (nejvýše 2-3 účastníci). Nastavte podpůrnou vrstvu pro vysoký výkon a zajistěte tak, že hovory s vícero účastníky budou hladce fungovat.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Provozování režimu „conversation_cluster“ podpůrné vrstvy pro vysoký výkon je zastaralé a v nadcházející verzi už nebude podporováno. Podpůrná vrstva dnes už obsahuje skutečné klastrování, které by mělo být použito namísto toho.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Definování vícero podpůrných vrstev pro vysoký výkon je zastaralé a v nadcházející verzi už nebude podporováno. Namísto toho by rozdělování zátěže mělo být nastaveno ve spojení se signalizačními servery v clusteru a ten pak zadán v nastavení Talk.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Uložený veřejný klíč pro použitý algoritmus %1$s neodpovídá uloženému soukromému klíči. Opravte tuto chybu spuštěním %2$s.",
    "High-performance backend not configured correctly. Run %s for details." : "Podpůrná vrstva pro vysoký výkon není správně nastavená. Podrobnosti obdržíte spuštěním %s.",
    "High-performance backend not configured correctly" : "Podpůrná vrstva pro vysoký výkon není správně nastavená",
    "Error: Cannot connect to server" : "Chyba: K serveru se nedaří připojit",
    "Error: Server did not respond with proper JSON" : "Chyba: Odpověď ze serveru nemá platný JSON formát",
    "Error: Certificate expired" : "Chyba: platnost certifikátu skončila",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Chyba: systémové časy Nextcloud serveru a serveru s podpůrnou vrstvou pro vysoký výkon se liší. Ověřte, že oba servery jsou napojeny na stejný časový server nebo jejich čas ručně sesynchronizujte.",
    "Could not get version" : "Nedaří se získat verzi",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Chyba: Provozovaná verze: {version}; Server je třeba aktualizovat, aby byl kompatibilní s touto verzí Talk",
    "Error: Server responded with: {error}" : "Chyba: Odpověď ze serveru: {error}",
    "Error: Unknown error occurred" : "Chyba: Došlo k neznámé chybě",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Varování: provozovaná verze: {version}; Server nepodporuje všechny funkce této verze Talk – chybějící funkce: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Pokud je Nextcloud Talk provozován s podpůrnou vrstvou pro vysoký výkon, je vřele doporučováno nastavit mezipaměť v operační paměti.",
    "Client Push" : "Služba klient Push",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Služba klient Push je nainstalovaná a bude zlepšovat včasnost doručení notifikací v Talk.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} není nainstalované. To může vést k prodlevě doručování notifikací z Talk.",
    "Recording backend" : "Podpůrná vrstva pro nahrávání",
    "Using the recording backend requires a High-performance backend." : "Aby bylo možné používat podpůrnou vrstvu pro pořizování nahrávek, je třeba mít vrstvu pro vysoký výkon.",
    "No recording backend configured" : "Nenastavena žádná podpůrná vrstva pro pořizování nahrávek",
    "SIP configuration" : "Nastavení SIP",
    "Using the SIP functionality requires a High-performance backend." : "Aby bylo možné používat funkci pro SIP, je třeba mít vrstvu pro vysoký výkon.",
    "No SIP backend configured" : "Nenastavena žádná podpůrná vrstva pro SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "Neplatné datum, je třeba aby formát byl RRRR-MM-DD",
    "Conversation not found" : "Konverzace nenalezena",
    "Path is already shared with this conversation" : "Popis umístění už je touto konverzací sdílen",
    "Chat, video & audio-conferencing using WebRTC" : "Chat, video a audiokonference používající WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Chat, video a audio konference využívající WebRTC\n\n* 💬 **Chat** Nextcloud Talk je vybavený jednoduchým textovým chatem, který Vám umožňuje sdílet nebo nahrávat soubory z Nextcloud Souborů nebo přímo ze zařízení a zmiňovat ostatní účastníky chatu.\n* 👥 **Soukromé, skupinové i veřejné a heslem chráněné hovory!** Pozvěte někoho, třeba celou skupinu lidí nebo pošlete veřejně přístupný odkaz jako pozvánku pro připojení k hovoru.\n* 🌐 **Federované chaty** Chatujte s ostatními uživateli Nextcloud na jejich serverech.\n* 💻 **Sdílení obrazovky!** Sdílejte to co vidíte na své obrazovce s ostatními účastníky hovoru.\n* 🚀 **Integrace s dalšími aplikacemi Nextcloud** například se Soubory, Kalendářem, Uživatelským stavem, Nástěnkou, Flow, Mapami, Smart Pickerem, Kontakty, Deck a mnoha dalšími.\n* 🌉 **Synchronizujte s jinými poskytovateli chatu** [Matterbridge](https://github.com/42wim/matterbridge/) je do Talk integrovaný, což znamená že můžete jednoduše synchronizovat mnoho dalších chatovacích řešení do Nextcloud Talk a naopak.",
    "Leave call" : "Opustit hovor",
    "Navigating away from the page will leave the call in {conversation}" : "Opuštění této stránky nepřeruší hovor v {conversation}",
    "Stay in call" : "Neopustit hovor",
    "Error occurred when getting the conversation information" : "Při získávání informací o konverzaci došlo k chybě",
    "Discuss this file" : "Diskutujte o tomto souboru",
    "Share this file with others to discuss it" : "Sdílet tento soubor s ostatními k diskuzi",
    "Share this file" : "Sdílet tento soubor",
    "Join conversation" : "Vstupte do konverzace",
    "This conversation is password-protected." : "Tato konverzace je chráněna heslem.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Bylo rozpoznáno několik neplatných pokusů o zadání hesla z vaší IP adresy. Další pokus bude proto možný až za 30 sekund.",
    "The password is wrong. Try again." : "Heslo není správné. Zkuste to znovu.",
    "Password" : "Heslo",
    "Submit" : "Odeslat",
    "Error requesting the password." : "Chyba při požadavku na heslo.",
    "Request password" : "Vyžadovat heslo",
    "This conversation has ended" : "Tato konverzace skončila",
    "Error occurred when joining the conversation" : "Při připojování se ke konverzaci došlo k chybě",
    "Close Talk sidebar" : "Zavřít postranní panel Talk",
    "Open Talk sidebar" : "Otevřít postranní panel Talk",
    "Everyone" : "Všichni",
    "Users and moderators" : "Uživatelé a moderátoři",
    "Moderators only" : "Pouze moderátoři",
    "Disable calls" : "Neumožnit hovory",
    "Save changes" : "Uložit změny",
    "Saving …" : "Ukládání …",
    "Saved!" : "Uloženo",
    "Limit to groups" : "Omezit na skupiny",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Když je vybrána alespoň jedna skupina, pak se konverzace mohou účastnit pouze lidé z uvedených skupin.",
    "Guests can still join public conversations." : "Hosté se pořád mohou připojit k veřejným konverzacím.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Uživatelé, kteří přestanou Talk používat  budou pořád uvedeni jako účastníci v jejich předchozích konverzacích a také jejich zprávy budou zachovány.",
    "Limit using Talk" : "Omezit používání Talk",
    "Limit creating a public and group conversation" : "Omezit vytváření veřejných a skupinových konverzací",
    "Limit creating conversations" : "Omezit vytváření konverzací",
    "Limit starting a call" : "Omezit zahájení hovoru",
    "Limit starting calls" : "Omezit zahajování hovorů",
    "When a call has started, everyone with access to the conversation can join the call." : "Poté, co konverzace započne, kdokoli s přístupem ke konverzaci se může připojit k hovoru.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Na tomto serveru jsou nainstalovány následující automaty. V dokumentaci naleznete podrobnosti ohledně toho, jak {linkstart1}vytvořit svůj vlastní automat{linkend} nebo {linkstart2}seznam automatů{linkend} pro zapnutí na vašem serveru.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Na tomto serveru nejsou nainstalovány žádné automaty. V dokumentaci naleznete podrobnosti ohledně toho, jak {linkstart1}vytvořit svůj vlastní automat{linkend} nebo {linkstart2}seznam automatů{linkend} pro zapnutí na vašem serveru.",
    "Description is not provided" : "Popis není poskytnut",
    "Locked for moderators" : "Uzamčeno jen pro moderátory",
    "Enabled" : "Zapnuto",
    "Disabled" : "Vypnuto",
    "Bots settings" : "Nastavení ohledně automatů",
    "State" : "Stav",
    "Name" : "Jméno",
    "Last error" : "Poslední chyba",
    "Total errors count" : "Celkový počet chyb",
    "Find more bots" : "Najít více automatů",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Důvěryhodné servery je možné nastavit na {linkstart}Stránce nastavení sdílení{linkend}.",
    "Beta" : "Vývojové",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Federované chaty a volání už fungují. Obsluha příloh přijde v budoucí verzi.",
    "Enable Federation in Talk app" : "Zapnout federování v aplikaci Talk",
    "Permissions" : "Oprávnění",
    "Allow users to be invited to federated conversations" : "Umožnit aby uživatelé byli zváni do federovaných konverzací",
    "Allow users to invite federated users into conversation" : "Umožnit uživatelům zvát federované uživatele do konverzací",
    "Only allow to federate with trusted servers" : "Umožnit federování pouze s důvěryhodnými servery",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Když je vybrána alespoň jedna skupina, pak zvát federované uživatele do konverzace mohou pouze lidé z uvedených skupin.",
    "Groups allowed to invite federated users" : "Skupiny které mohou zvát federované uživatele",
    "Select groups …" : "Vybrat skupiny …",
    "All messages" : "Všechny zprávy",
    "@-mentions only" : "Pouze zmínky ve stylu @jméno",
    "Off" : "Vypnuto",
    "General settings" : "Obecná nastavení",
    "Default notification settings" : "Výchozí nastavení upozorňování",
    "Default group notification" : "Výchozí upozornění pro skupinu",
    "Default group notification for new groups" : "Výchozí upozorňování pro nové skupiny",
    "Integration into other apps" : "Napojení na další aplikace",
    "Allow conversations on files" : "Povolit konverzace u souborů",
    "Allow conversations on public shares for files" : "Povolit konverzaci u veřejných souborů pro sdílení",
    "End-to-end encrypted calls" : "Hovory šifrované mezi koncovými body",
    "Enable encryption" : "Šifrovat",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Hovory šifrované mezi koncovými body s nastaveným mostem pro SIP vyžadují novější verzi podpůrné vrstvy pro vysoký výkon a mostu pro SIP.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Mobilní klienti v tuto chvíli nepodporují hovory šifrované mezi koncovými body.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Kliknutím na výše uvedené tlačítko budou údaje z formuláře odeslány na servery společnosti Struktur AG. Podrobnosti naleznete na {linkstart}spreed.eu{linkend}.",
    "Pending" : "Čeká",
    "Error" : "Chyba",
    "Blocked" : "Blokovaný",
    "Active" : "Aktivní",
    "Expired" : "Platnost skončila",
    "Never" : "Nikdy",
    "The trial could not be requested. Please try again later." : "Nepodařilo se zažádat o zkušební období. Prosím zkuste to znovu později.",
    "The account could not be deleted. Please try again later." : "Účet se nepodařilo smazat. Prosím zkuste to znovu později.",
    "Hosted High-performance backend" : "Hostovaná podpůrná vrstva pro vysoký výkon",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Náš partner, společnost Struktur AG poskytuje službu, u které je možné si zažádat o hostovaný signalizační server. Stačí pouze vyplnit níže uvedený formulář a vaše instance Nextcloud provede žádost Jakmile je pro vás vytvořen server, přihlašovací údaje budou vyplněny automaticky. Toto přepíše existující nastavení pro signalizační server.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Pokud váš účet pro vysoce výkonnou podpůrnou vrstvu obsahuje funkci STUN a/nebo TURN, nastavení budou příslušně zaktualizována.",
    "URL of this Nextcloud instance" : "URL adresa této instance Nextcloud",
    "Full name of the user requesting the trial" : "Celé jméno uživatele, žádajícího o zkušební období",
    "Email of the user" : "E-mail uživatele",
    "Language" : "Jazyk",
    "Country" : "Země",
    "Request signaling server trial" : "Požádat o zkušební období signalizačního serveru",
    "You can see the current status of your hosted signaling server in the following table." : "Stávající stav vašeho hostovaného signálního serveru naleznete v následující tabulce.",
    "Status" : "Stav",
    "Created at" : "Vytvořeno",
    "Expires at" : "Platnost končí",
    "Limits" : "Omezení",
    "STUN included" : "STUN obsaženo",
    "Yes" : "Ano",
    "No" : "Ne",
    "TURN included" : "TURN obsaženo",
    "Delete the signaling server account" : "Smazat účet na signalizačním serveru",
    "_%n user_::_%n users_" : ["%n uživatel","%n uživatelé","%n uživatelů","%n uživatelé"],
    "Installed version: {version}" : "Nainstalovaná verze: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Pro propojení Nextcloud Talk s některými ostatními službami je možné nainstalovat Matterbridge, podrobnosti viz {linkstart1}stránka na GitHub{linkend}. Stažení a instalace aplikace může chvíli trvat. V případě překročení časového limitu ji prosím nainstalujte ručně z {linkstart2}Nextcloud katalogu aplikací{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Spustitelný soubor nemá správná oprávnění. Ověřte, že spustitelný soubor s Matterbridge je vlastněn správným uživatelem a je spustitelný. Je k nalezení v „/…/nextcloud/apps/talk_matterbridge/bin/“.",
    "Matterbridge binary was not found or couldn't be executed." : "Spustitelný soubor s matterbridge nebyl nalezen nebo ho nebylo možné spustit.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Je také možné nastavit popis umístění spustitelného souboru s Matterbridge ručně a to v nastavení. Podrobnosti naleznete v {linkstart}dokumentaci k napojení Matterbridge{linkend}.",
    "Downloading …" : "Stahování …",
    "Install Talk Matterbridge" : "Nainstalovat Matterbridge pro Talk",
    "An error occurred while installing the Matterbridge app" : "Došlo k chybě při instalaci aplikace Matterbridge",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Při instalaci Matterbridge pro Talk došlo k chybě. Prosím nainstalujte ho ručně",
    "Failed to execute Matterbridge binary." : "Nepodařilo se spustit spustitelný soubor od Matterbridge.",
    "Matterbridge integration" : "Napojení na Matterbridge",
    "Enable Matterbridge integration" : "Zapnout napojení na Matterbridge",
    "Status: Checking connection" : "Stav: Kontrola připojení",
    "OK: Running version: {version}" : "OK: Spuštěná verze: {version}",
    "Error: Server seems to be a Signaling server" : "Chyba: zdá se, že server je signalizujícím serverem",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Chyba: systémové časy Nextcloud serveru a serveru s podpůrnou vrstvou pro pořizování nahrávek se liší. Ověřte, že oba servery jsou napojeny na stejný časový server nebo jejich čas ručně sesynchronizujte.",
    "Recording backend URL" : "URL podpůrné vrstvy pro nahrávání",
    "Validate SSL certificate" : "Ověřovat si SSL certifikát",
    "Delete this server" : "Smazat tento server",
    "Test this server" : "Vyzkoušet tento server",
    "Disabled for all calls" : "Vypnuto pro všechna volání",
    "Enabled for all calls" : "Zapnuto pro všechna volání",
    "Configurable on conversation level by moderators" : "Nastavitelné moderátory v rámci konverzace",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHP nastavení „upload_max_filesize“ nebo „post_max_size“ umožní nahrání souborů velkých nejvýše {maxUpload}.",
    "Recording backend settings saved" : "Nastavení pro podpůrnou vrstvu pro nahrávání uložena",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Moderátorům bude umožněno zapnout souhlas v rámci konverzace. Souhlas s pořízením nahrávky bude vyžadován od každého z účastníků před každým připojením k hovoru v této konverzaci.",
    "The consent to be recorded will be required for each participant before joining every call." : "Souhlas s nahráváním bude vyžadován od každého z účastníků před každým připojením k hovoru v této konverzaci.",
    "The consent to be recorded is not required." : "Souhlas s nahráváním není vyžadován.",
    "Recording backend configuration is only possible with a High-performance backend." : "Nastavování podpůrné vrstvy pro pořizování nahrávek je možné pouze při použití podpůrné vrstvy pro vysoký výkon.",
    "Add a new recording backend server" : "Přidat nový server podpůrné vrstvy pro nahrávávání",
    "Shared secret" : "Předsdílené heslo",
    "Recording consent" : "Souhlas s nahráváním",
    "Recording transcription" : "Přepis nahrávky",
    "Automatically transcribe call recordings with a transcription provider" : "Automaticky přepsat nahrávky hovorů prostřednictvím poskytovatele přepisů",
    "Automatically summarize call recordings with transcription and summary providers" : "Automaticky vytvářet souhrn nahrávek hovorů prostřednictvím poskytovatele přepisů a souhrnů",
    "SIP configuration saved!" : "Nastavení pro SIP nastaveno!",
    "SIP configuration is only possible with a High-performance backend." : "Nastavení SIP je možné pouze při použití podpůrné vrstvy pro vysoký výkon.",
    "Enable SIP Dial-out option" : "Zapnout SIP volání odsud",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Aby podporoval SIP volání odsud, je třeba aktualizovat signalizační server.",
    "Do not show SIP Dial-out caller number" : "Nezobrazovat číslo volajícího SIP volání ven",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Anonymní čísla by se měla příjemci volání zobrazovat jako „neznámé“ nebo „skryté číslo“",
    "Dial-out number" : "Telefonní číslo, ze kterého zavolat",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Číslo ve formátu E164 sloužící jako náhradní číslo volajícího pro odchozí volání",
    "Dial-out prefix" : "Předpona, ze které zavolat",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Předpona pro nastavené číslo uživatele pro odchozí volání (výchozí je `+`)",
    "Restrict SIP configuration" : "Omezit nastavení SIP",
    "Enable SIP configuration" : "Zapnout nastavení SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "SIP mohou zapnout pouze členové následujících skupin a to jen v konverzacích, které moderují",
    "Phone number (Country)" : "Telefonní číslo (země)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Tato informace je odeslána ve zvacích e-mailech a také zobrazována v postranním panelu všem účastníkům.",
    "Nextcloud base URL" : "Základ URL Nextcloud",
    "Talk Backend URL" : "URL podpůrné vrstvy Talk",
    "WebSocket URL" : "URL WebSocket",
    "Available features" : "Funkce k dispozici",
    "Error: Websocket connection failed" : "Chyba: Websocket připojení se nezdařilo",
    "Error code" : "Kód chyby",
    "Error message" : "Chybové hlášení",
    "Error: Websocket connection failed. Check browser console" : "Chyba: Websocket připojení se nezdařilo. Podívejte se do konzole prohlížeče",
    "High-performance backend URL" : "URL adresa podpůrné vrstvy pro vysoký výkon",
    "Missing High-performance backend warning hidden" : "Varování o chybějící podpůrné vrstvě pro vysoký výkon skryto",
    "High-performance backend settings saved" : "Nastavení pro podpůrnou vrstvu pro vysoký výkon uložena",
    "Nextcloud Talk setup not complete" : "Nastavení Nextcloud Talk nedokončeno",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Mějte na paměti, že při volání s více než 2 účastníky bez podpůrné vrstvy pro vysoký výkon budou účastníci nejspíš pociťovat problémy s konektivitou a vysoké vytížení účastnících se zařízení.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Pro hladké fungování hovorů s vícero účastníky nainstalujte podpůrnou vrstvu pro vysoký výkon.",
    "Nextcloud portal" : "Portál Nextcloud",
    "Quick installation guide" : "Stručná instalační příručka",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Pro hovory a konverzace s vícero účastníky je zapotřebí podpůrné vrstvy pro vysoký výkon. Bez ní všichni účastníci musejí odesílat své vlastní video jednotlivě pro každého z ostatních účastníků, což nejspíš způsobí problémy s konektivitou a vysokým vytížením zařízení účastníků.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Při používání Nextcloud Talk ve spojení s podpůrnou vrstvou pro vysoký výkon, je doporučeno nastavit distribuovanou mezipaměť.",
    "Add High-performance backend server" : "Přidat server podpůrné vrstvy pro vysoký výkon",
    "Warn about connectivity issues in calls with more than 2 participants" : "Varovat před problémy s konektivitou u volání s více než 2 účastníky",
    "STUN server URL" : "URL adresa STUN serveru",
    "The server address is invalid" : "Adresa serveru není platná",
    "STUN settings saved" : "Nastavení pro STUN uložena",
    "STUN servers" : "Servery STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Server STUN je používán ke zjištění veřejné IP adresy účastníků schovaných za směrovačem (router).",
    "Add a new STUN server" : "Přidat nový STUN server",
    "{schema} scheme must be used with a domain" : "společně s doménou je třeba použít schéma {schema}",
    "{option1} and {option2}" : "{option1} a {option2}",
    "{option} only" : "Pouze {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: TURN server odpověděl úspěšnými ICE kandidáty",
    "Error: No working ICE candidates returned by the TURN server" : "Chyba: TURN server neodpověděl žádnými fungujícími ICE kandidáty",
    "Testing whether the TURN server returns ICE candidates" : "Zkoušení zda TURN server odpoví ICE kandidáty",
    "TURN server schemes" : "Popis TURN serveru",
    "TURN server URL" : "URL adresa TURN serveru",
    "TURN server secret" : "Kód pro TURN server",
    "TURN server protocols" : "Protokoly TURN serveru",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURN server slouží jako proxy pro provoz od účastníků, kteří se nacházejí za bránou firewall. Pokud se jednotliví účastníci nemohou spojit s ostatními, nejspíš je zapotřebí TURN server. Pokyny k nastavení viz {linkstart}tato dokumentace{linkend} .",
    "TURN settings saved" : "Nastavení pro TURN uložena",
    "TURN servers" : "TURN servery",
    "Add a new TURN server" : "Přidat nový TURN server",
    "Failed" : "Nezdařilo se",
    "OK" : "OK",
    "Checking …" : "Kontrola …",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Nezdar: WebAssembly je vypnuté nebo nepodporované prohlížečem. Pro provedení kontroly zapněte WebAssembly nebo použijte prohlížeč, který jej podporuje.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Nezdařilo se: webový server nevrátil správně soubory „.wasm“ a „.tflite“. Podívejte se do sekce „Požadavky na systém“ v dokumentaci k Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: server správně vrátil soubory „.wasm“ a „.tflite“.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Zdá se, že nastavení PHP a Apache nejsou slučitelná. Poznamenejme, že PHP je možné použít pouze s modulem MPM_PREFORK a PHP-FPM je možné použít pouze s modulem MPM_EVENT.",
    "Web server setup checks" : "Kontroly nastavení webového serveru",
    "Files required for virtual background can be loaded" : "Nedaří se načíst soubory, potřebné pro virtuální pozadí",
    "Federated user" : "Federovaný uživatel",
    "Assign participants to rooms" : "Přiřadit účastníkům místnosti",
    "Configure breakout rooms" : "Nastavit přestávkové místnosti",
    "Number of breakout rooms" : "Počet přestávkových místností",
    "You can create from 1 to 20 breakout rooms." : "Je možné vytvořit 1 až 20 přestávkových místností.",
    "Assignment method" : "Metoda přiřazování",
    "Automatically assign participants" : "Automaticky přiřadit účastníky",
    "Manually assign participants" : "Přiřadit účastníky ručně",
    "Allow participants to choose" : "Umožnit účastníkům zvolit",
    "Create rooms" : "Vytvořit místnosti",
    "Confirm" : "Potvrdit",
    "Create breakout rooms" : "Vytvořit přestávkové místnosti",
    "Reset" : "Vrátit na výchozí hodnoty",
    "Delete breakout rooms" : "Smazat přestávkové místnosti",
    "Room {roomNumber}" : "Místnost {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Stávající přestávkové místnosti a nastavení budou ztraceny",
    "Cancel" : "Storno",
    "Unassigned participants" : "Nepřiřazení účastníci",
    "Back" : "Zpět",
    "Assign" : "Přidělit",
    "Add participant \"{user}\"" : "Přidat účastníka „{user}“",
    "Now" : "Nyní",
    "Invalid calendar selected" : "Vybrán neplatný kalendář",
    "Invalid start time selected" : "Vybrán neplatný čas zahájení",
    "Invalid end time selected" : "Vybrán neplatný čas skončení",
    "Unknown error occurred" : "Došlo k neznámé chybě",
    "Sending no invitations" : "Pozvánky nebudou zaslány",
    "{participant0} will receive an invitation" : "{participant0} obdrží pozvánku",
    "{participant0} and {participant1} will receive invitations" : "{participant0} a {participant1} obdrží pozvánky",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} a %n další obdrží pozvánky","{participant0}, {participant1} a %n další obdrží pozvánky","{participant0}, {participant1} a %n dalších obdrží pozvánky","{participant0}, {participant1} a %n další obdrží pozvánky"],
    "Invite {user}" : "Pozvat {user}",
    "Invite all users and emails in this conversation" : "Pozvat všechny uživatele a e-maily do konverzace",
    "Meeting created" : "Schůzka vytvořena",
    "Upcoming meetings" : "Nadcházející schůzky",
    "Loading …" : "Načítání …",
    "No upcoming meetings" : "Žádné nadcházející schůzky",
    "Schedule a meeting" : "Naplánovat schůzku",
    "Meeting title" : "Název schůzky",
    "From" : "Od",
    "To" : "Pro",
    "Calendar" : "Kalendář",
    "Attendees" : "Účastníci",
    "No other participants to send invitations to." : "Žádní ostatní účastníci, kterým poslat pozvánku.",
    "Add attendees" : "Přidat účastníky",
    "Save" : "Uložit",
    "Search participants" : "Vyhledat účastníky",
    "No results" : "Žádné výsledky",
    "Done" : "Dokončeno",
    "Disable live transcription" : "Vypnout přepis v reálném čase",
    "Enable live transcription (generated by AI)" : "Zapnout průběžné přepisování do textu (vytvářeno AI)",
    "Disable live translation" : "Vypnout překlad v reálném čase",
    "Enable live translation (generated by AI)" : "Zapnout průběžné překládání (vytvářeno AI)",
    "Original language: {languageName}" : "Původní jazyk: {languageName}",
    "Translated language" : "Přeložený jazyk",
    "Translated language: {languageName}" : "Přeložený jazyk: {languageName}",
    "Raise hand" : "Hlásit se",
    "Raise hand (R)" : "Hlásit se (R)",
    "Lower hand" : "Přestat se hlásit",
    "Lower hand (R)" : "Přestat se hlásit (R)",
    "Exit full screen (F)" : "Opustit režim celé obrazovky (F)",
    "Full screen (F)" : "Spustit režim celé obrazovky (F)",
    "Speaker view" : "Zobrazení řečníka",
    "Grid view" : "Zobrazení v mřížce",
    "Error when trying to load the available live transcription languages" : "Chyba při pokusu o načtení jazyků, které jsou pro průběžný přepis k dispozici",
    "Failed to enable live transcription" : "Nepodařilo se zapnout průběžné vytváření přepisu",
    "Failed to enable live translations" : "Nepodařilo se zapnout průběžné překládání",
    "Failed to disable live translations" : "Nepodařilo se vypnout průběžné překládání",
    "Recording consent is required" : "Je vyžadován souhlas s nahráváním",
    "This conversation is read-only" : "Tato konverzace je pouze pro čtení",
    "Conversation not found or not joined" : "Konverzace nenalezena nebo jste do ní ještě nevstoupili",
    "Lobby is still active and you're not a moderator" : "Čekárna je pořád aktivní a nejste moderátorem",
    "Connection failed" : "Připojení se nezdařilo",
    "Reload" : "Načíst znovu",
    "{nickName} raised their hand." : "{nickName} se přihlásil(a) o slovo.",
    "A participant raised their hand." : "Účastník se hlásí.",
    "Collapse stripe" : "Sbalit pruh",
    "Expand stripe" : "Rozbalit pruh",
    "Previous page of videos" : "Předchozí stránka s videi",
    "Next page of videos" : "Další stránka s videi",
    "Connecting …" : "Připojování …",
    "Calling …" : "Volání …",
    "Waiting for {user} to join the call" : "Čeká se, až se {user} připojí k hovoru",
    "Waiting for others to join the call …" : "Čekání na ostatní, až se připojí k hovoru …",
    "You can invite others in the participant tab of the sidebar" : "Ostatní je možné pozvat v kartě účastníci (na postranním panelu)",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Ostatní je možné pozvat na kartě účastníci v bočním panelu nebo sdílet tento odkaz pro pozvání ostatních!",
    "Share this link to invite others!" : "Pro pozvání dalších lidí sdílejte tento odkaz!",
    "Copy link" : "Zkopírovat odkaz",
    "You are not allowed to enable audio" : "Nemáte oprávnění zapnout přenos zvuku od vás",
    "No audio. Click to select device" : "Žádný zvuk – kliknutím vyberte zařízení.",
    "Mute audio" : "Ztlumit zvuk",
    "Mute audio (M)" : "Ztlumit zvuk (M)",
    "Unmute audio" : "Zrušit ztlumení zvuku",
    "Unmute audio (M)" : "Zrušit ztlumení zvuku (M)",
    "None" : "Žádné",
    "Select a microphone" : "Vyberte mikrofon",
    "Select a speaker" : "Vybrat reproduktor",
    "Microphone settings" : "Nastavení mikrofonu",
    "Check devices" : "Zkontrolovat zařízení",
    "Access to camera was denied" : "Přístup ke kameře byl odepřen",
    "Error while accessing camera: It is likely in use by another program" : "Chyba při přistupování ke kameře: nejspíš je využívána jiným programem",
    "Error while accessing camera" : "Chyba při přístupu ke kameře",
    "You have been muted by a moderator" : "Byli jste ztlumeni moderátorem",
    "Hide presenter video" : "Krýt video prezentujícího",
    "You are not allowed to enable video" : "Nemáte oprávnění zapnout přenos z kamery od vás",
    "No video. Click to select device" : "Žádné video – kliknutím vyberte zařízení.",
    "Disable video" : "Vypnout video",
    "Disable video (V)" : "Vypnout obraz (V)",
    "Enable video" : "Povolit video",
    "Enable video (V)" : "Zapnout obraz (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Zapnout video – při jeho prvním zapnutí bude spojení nakrátko přerušeno",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Zapnout obraz (V) – Při prvním spuštění bude vaše spojení nakrátko přerušeno",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Zapnout video. Při jeho prvním zapnutí bude spojení nakrátko přerušeno",
    "Select a video device" : "Vyberte videozařízení",
    "Show presenter" : "Zobrazit přezentujícího",
    "You" : "Vy",
    "Mute" : "Ztlumit",
    "Muted" : "Ztlumeno",
    "Show screen" : "Ukázat obrazovku",
    "Stop following" : "Přestat následovat",
    "Connection could not be established …" : "Spojení se nedaří navázat …",
    "Connection was lost and could not be re-established …" : "Spojení bylo ztraceno a nedaří se ho opětovně navázat …",
    "Connection could not be established. Trying again …" : "Spojení se nepodařilo navázat. Zkouší se znovu …",
    "Connection lost. Trying to reconnect …" : "Spojení ztraceno. Pokus o opětovné připojení…",
    "Connection problems …" : "Problémy s připojením…",
    "Collapse" : "Sbalit",
    "Expand" : "Rozbalit",
    "You need to be logged in to upload files" : "Pro nahrávání souborů je třeba, abyste byli přihlášení",
    "Drop your files to upload" : "Přetáhněte sem soubor, které chcete nahrát",
    "Conversation messages" : "Zprávy v konverzaci",
    "Scroll to bottom" : "Odrolovat na konec",
    "Post message" : "Odeslat zprávu",
    "Federated conversation" : "Federovaná konverzace",
    "Public conversation" : "Veřejná konverzace",
    "Favorite" : "Oblíbený",
    "Banned users" : "Vyloučení uživatelé",
    "Manage the list of banned users in this conversation." : "Spravovat seznam vyloučených uživatelů v této konverzaci.",
    "Manage bans" : "Spravovat vyloučení",
    "No banned users" : "Žádní vyloučení uživatelé",
    "Banned by:" : "Vyloučil(a):",
    "Date:" : "Datum:",
    "Note:" : "Poznámka:",
    "Hide details" : "Skrýt podrobnosti",
    "Show details" : "Zobrazit podrobnosti",
    "Unban" : "Zrušit vyloučení",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Nadpis a popis je možné změnit v {linkstart}Kalendáři ↗{linkend}.",
    "Error while updating conversation name" : "Chyba při aktualizování názvu konverzace",
    "Error while updating conversation description" : "Při úpravě popisu konverzace se vyskytla chyba",
    "Enter a name for this conversation" : "Zadejte název pro tuto konverzaci",
    "Edit conversation name" : "Upravit název konverzace",
    "Edit conversation description" : "Upravit popis konverzace",
    "Enter a description for this conversation" : "Přidat popis pro tuto konverzaci",
    "Picture" : "Obrázek",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "V této konverzaci je možné zapnout následující automaty. Pokud chcete na tomto serveru mít nainstalovány další, obraťte se na jeho správce.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Na tomto serveru nejsou nainstalovány žádné automaty. Pokud chcete na tomto serveru mít nainstalovány další, obraťte se na jeho správce.",
    "Disable" : "Vypnout",
    "Enable" : "Povolit",
    "Breakout rooms" : "Přestávkové místnosti",
    "Manage breakout rooms" : "Spravovat přestávkové místnosti",
    "Set up breakout rooms for this conversation" : "Vytvořte pro tuto konverzaci přestávkové místnosti",
    "Please select a valid PNG or JPG file" : "Vyberte platný PNG nebo JPG soubor",
    "Choose your conversation picture" : "Zvolte si obrázek pro konverzaci",
    "Choose" : "Vybrat",
    "Error setting conversation picture" : "Chyba při nastavování obrázku konverzace",
    "Could not set the conversation picture: {error}" : "Nepodařilo se nastavit obrázek konverzace: {error}",
    "Error cropping conversation picture" : "Chyba při ořezávání obrázku pro konverzaci",
    "Error removing conversation picture" : "Chyba při odebírání obrázku konverzace",
    "Set emoji as conversation picture" : "Nastavit emotikonu jako obrázek konverzace",
    "Set background color for conversation picture" : "Nastavit barvu pozadí pro obrázek konverzace",
    "Upload conversation picture" : "Nahrát obrázek konverzace",
    "Choose conversation picture from files" : "Zvolit obrázek konverzace ze souborů",
    "Remove conversation picture" : "Odebrat obrázek konverzace",
    "The file must be a PNG or JPG" : "Je třeba, aby soubor by PNG nebo JPG",
    "Set picture" : "Nastavit obrázek",
    "Default permissions modified for {conversationName}" : "Výchozí oprávnění změněna pro {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Nedaří se upravit výchozí oprávnění uživateli {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Upravit výchozí oprávnění pro účastníky v této konverzaci. Tato nastavení se nedotknou moderátorů.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Pokaždé když jsou v této sekci změněna oprávnění, budou ztracena předtím udělená uživatelsky určená oprávnění, přiřazená jednotlivým účastníkům.",
    "All permissions" : "Všechna oprávnění",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Účastníci mají oprávnění zahájit hovor, připojit se k hovoru, zapnout zvuk a video, a sdílení obrazovky.",
    "Restricted" : "Omezeno",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Účastníci se mohou připojovat k hovorům, ale už ne zapínat zvuk, ani video či sdílení obrazovky od nich, dokud jim moderátoři tato oprávnění neudělí ručně.",
    "Advanced permissions" : "Pokročilá oprávnění",
    "Edit permissions" : "Upravit oprávnění",
    "Conversation settings" : "Nastavení konverzace",
    "Basic Info" : "Základní informace",
    "Personal" : "Osobní",
    "Moderation" : "Moderování",
    "Setup overview" : "Přehled nastavení",
    "Live transcription" : "Přepis v reálném čase",
    "Enable live transcription" : "Zapnout přepis v reálném čase",
    "Breakout Rooms" : "Přestávkové místnosti",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Automaty",
    "Danger zone" : "Nebezpečná zóna",
    "Archive conversation" : "Archivovat konverzaci",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Archivované konverzace jsou ve výchozím stavu ze seznamu konverzací skryté. Nicméně objeví se při hledání podle názvu konverzace nebo na seznamu archivovaných konverzací.",
    "Do you really want to leave \"{displayName}\"?" : "Opravdu chcete „{displayName}“ opustit?",
    "You can archive this conversation instead." : "Namísto toho můžete tuto konverzaci archivovat.",
    "Leave conversation" : "Opustit konverzaci",
    "You need to promote a new moderator before you can leave the conversation" : "Než budete moci konverzaci opustit, je třeba předat někomu roli moderátora",
    "Delete conversation" : "Smazat konverzaci",
    "Do you really want to delete \"{displayName}\"?" : "Opravdu chcete smazat „{displayName}“?",
    "Error while deleting conversation" : "Chyba při mazání konverzace",
    "Delete all chat messages" : "Smazat všechny zprávy chatu",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Opravdu chcete smazat všechny zprávy v „{displayName}“?",
    "Error while clearing chat history" : "Chyba při mazání historie konverzace",
    "Be careful, these actions cannot be undone." : "Opatrně, tyto kroky nelze vrátit zpět.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Jakmile opustíte konverzaci, budete v případě těch uzavřených potřebovat k opětovnému připojení pozvánku. K otevřené konverzaci se můžete znovu připojit kdykoli.",
    "Permanently delete this conversation." : "Nadobro smazat tuto konverzaci.",
    "Delete chat messages" : "Smazat zprávy chatu",
    "Permanently delete all the messages in this conversation." : "Nadobro smazat veškeré zprávy v této konverzaci.",
    "_%n hour_::_%n hours_" : ["%n hodina","%n hodiny","%n hodin","%n hodiny"],
    "_%n day_::_%n days_" : ["%n den","%n dny","%n dnů","%n dny"],
    "_%n week_::_%n weeks_" : ["%n týden","%n týdny","%n týdnů","%n týdny"],
    "Custom expiration time" : "Uživatelsky určený okamžik skončení platnosti",
    "Message expiration disabled" : "Ukončení platnosti zprávy vypnuto",
    "Message expiration set: {duration}" : "Okamžik skončení platnosti zprávy nastaven na: {duration}",
    "Error when trying to set message expiration" : "Chyba při pokusu o nastavení konce platnosti zprávy",
    "Message expiration" : "Skončení platnosti zprávy",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Platnost zpráv v chatu je možné ukončit po uplynutí zadané doby. Pozn.: Soubory nasdílené v chatu nebudou vlastníkovi smazány, ale už nadále nebudou sdíleny v konverzaci.",
    "Set message expiration" : "Nastavit skončení platnosti zprávy",
    "Current message expiration" : "Stávající doba platnosti zprávy",
    "Password copied to clipboard" : "Heslo zkopírováno do schránky",
    "Password could not be copied" : "Heslo se nepodařilo zkopírovat",
    "Guest access" : "Přístup pro hosty",
    "Breakout rooms are not allowed in public conversations." : "Přestávkové místnosti nejsou ve veřejných konverzacích povoleny.",
    "Allow guests to join this conversation via link" : "Umožnit hostům, připojit se k této konverzace prostřednictvím odkazu.",
    "Password protection" : "Ochrana heslem",
    "This conversation is password-protected. Guests need password to join" : "Tato konverzace je chráněna heslem. Hosté pro připojení potřebují heslo",
    "Password protection is needed for public conversations" : "Veřejné konverzace vyžadují heslo",
    "Set a password" : "Nastavit heslo",
    "Change password" : "Změnit heslo",
    "Enter new password" : "Zadejte nové heslo",
    "Save password" : "Uložit heslo",
    "Copy password" : "Zkopírovat heslo",
    "Guests are allowed to join this conversation via link" : "Hostům je umožněno se do této konverzace připojovat prostřednictvím odkazu",
    "Guests are not allowed to join this conversation" : "Hostům není umožněno se do této konverzace připojovat",
    "Resend invitations" : "Znovu poslat pozvánky",
    "This conversation is open to both registered users and users created with the Guests app" : "Tato konverzace je otevřená jak registrovaným uživatelům, tak uživatelům, vytvořeným v aplikaci Hosté",
    "This conversation is open to registered users" : "Tato konverzace je otevřená pro registrované uživatele",
    "This conversation is limited to the current participants" : "Tato konverzace je omezená pouze na stávající účastníky",
    "You opened the conversation to both registered users and users created with the Guests app" : "Otevřeli jste konverzaci jak registrovaným uživatelům, tak uživatelům, vytvořeným aplikací Hosté",
    "Error occurred when opening or limiting the conversation" : "Při otevírání nebo omezování konverzace došlo k chybě",
    "Open conversation to registered users, showing it in search results" : "Otevřít konverzaci registrovaným uživatelům a zobrazovat jí ve výsledcích hledání",
    "Also open to users created with the Guests app" : "Také otevřít uživatelům, vytvořeným v aplikaci Hosté",
    "Open conversation" : "Otevřít konverzaci",
    "Set language spoken in calls" : "Nastavte jazyk, kterým se mluví v hovorech",
    "Languages could not be loaded" : "Jazyky se nepodařilo načíst",
    "Loading languages …" : "Načítání jazyků …",
    "Invalid language" : "Neplatný jazyk",
    "Default language (English)" : "Výchozí jazyk (angličtina)",
    "Default live transcription language set" : "Výchozí jazyk pro vytváření průběžného přepisu nastaven",
    "Live transcription language set: {languageName}" : "Jazyk pro vytváření průběžného přepisu nastaven: {languageName}",
    "Error when trying to set live transcription language" : "Chyba při pokusu o nastavení jazyka pro průběžný přepis",
    "Start time: {date}" : "Okamžik začátku: {date}",
    "Start time has been updated" : "Čas zahájení byl upraven",
    "Error occurred while updating start time" : "Při upravování času začátku došlo k chybě",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Zapnutí čekárny odebere z probíhajícího hovoru ty, kteří nejsou moderátory.",
    "Enable lobby, restricting the conversation to moderators" : "Zapnout čekárnu, omezit konverzaci pouze na moderátory",
    "Meeting start time" : "Okamžik zahájení schůzky",
    "Start time (optional)" : "Čas začátku (volitelný)",
    "Import email participants" : "Naimportovat e-mailové účastníky",
    "You can import a list of email participants from a CSV file." : "Seznam e-mailových účastníků je možné naimportovat z CSV souboru.",
    "Poll drafts" : "Koncepty anket",
    "Browse poll drafts" : "Procházet koncepty anket",
    "Error occurred when locking the conversation" : "Při uzamykání konverzace došlo k chybě",
    "Error occurred when unlocking the conversation" : "Při odemykání konverzace došlo k chybě",
    "Lock conversation" : "Uzamknout konverzaci",
    "This will also terminate the ongoing call." : "Toto ukončí i probíhající hovor.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Uzamknout konverzaci a zabránit tak komukoliv posílat do ní zprávy nebo zahajovat hovory",
    "Edit" : "Upravit",
    "More information" : "Podrobnosti",
    "Delete" : "Smazat",
    "Add new bridged channel to current conversation" : "Přidat nový můstkem napojený kanál do současné konverzace",
    "unknown state" : "neznámý stav",
    "running" : "spuštěné",
    "not running, check Matterbridge log" : "není spuštěné – zkontrolujte záznam událostí Matterbridge",
    "not running" : "nespuštěné",
    "Bridge saved" : "Můstek uložen",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Pomocí Matterbridge je možné napojit můstkem kanály z různých systémů pro okamžité posílání zpráv.",
    "More info on Matterbridge" : "Podrobnosti o Matterbridge",
    "Messaging systems" : "Systémy zasílání zpráv",
    "Enable bridge" : "Povolit můstek",
    "Show Matterbridge log" : "Zobrazit záznam událostí v Matterbridge",
    "Log content" : "Obsah záznamu událostí",
    "Only moderators are allowed to mention @all" : "Zmínit @all (všechny) je umožněno pouze moderátorům",
    "All participants are allowed to mention @all" : "Zmínit @all (všechny) je umožněno všem účastníkům",
    "Participants are now allowed to mention @all." : "Účastníkům je nyní umožněno zmínit @all (všechny).",
    "Mentioning @all has been limited to moderators." : "Zmiňování @all (všech) bylo omezeno pouze na moderátory.",
    "Allow participants to mention @all" : "Umožnit účastníkům zmínit @all (všechny)",
    "Mention permissions" : "Oprávnění pro zmiňování",
    "Notifications" : "Upozornění",
    "Notify about calls in this conversation" : "Upozorňovat na volání v této konverzaci",
    "Important conversation" : "Důležitá konverzace",
    "\"Do not disturb\" user status is ignored for important conversations" : "Stav uživatele „Nevyrušovat“ bude v případě důležitých konverzací ignorován",
    "Sensitive conversation" : "Citlivá konverzace",
    "Message preview will be disabled in conversation list and notifications" : "Náhled zprávy bude vypnut pro seznam konverzací a notifikace",
    "Recording consent is required for calls in this conversation" : "Souhlas s nahráváním je vyžadován pro volání v této konverzaci",
    "Recording consent is not required for calls in this conversation" : "Souhlas s nahráváním není pro volání v této konverzaci vyžadován",
    "Recording consent requirement was updated" : "Požadavek na souhlas s nahráváním byl zaktualizován",
    "Error occurred while updating recording consent" : "Při aktualizování souhlasu s nahráváním došlo k chybě",
    "Recording Consent" : "Souhlas s nahráváním",
    "Recording consent cannot be changed once a call or breakout session has started." : "Souhlas s nahráváním nelze po zahájení hovoru nebo přestávkové relace změnit.",
    "Require recording consent before joining call in this conversation" : "Vždy vyžadovat souhlas s nahráváním před připojením hovoru v této konverzaci.",
    "Recording consent is required for all calls" : "Souhlas s nahráváním je vyžadován pro všechna volání",
    "SIP dial-in is now possible without PIN requirement" : "Zavolat do hovoru prostřednictvím SIP je nyní možné i bez požadavku na PIN kód",
    "SIP dial-in is now enabled" : "SIP vytáčení je povoleno",
    "SIP dial-in is now disabled" : "SIP vytáčení je zakázáno",
    "Error occurred when enabling SIP dial-in" : "Při zapínání SIP vytáčení došlo k chybě",
    "Error occurred when disabling SIP dial-in" : "Při vypínání SIP vytáčení došlo k chybě",
    "Phone and SIP dial-in" : "Volání do telefonem a SIP",
    "Enable phone and SIP dial-in" : "Zapnout volání do konverzace telefonem a přes SIP protokol",
    "Allow to dial-in without a PIN" : "Umožnit zavolání do hovoru bez zadávání PIN kódu",
    "Ongoing" : "Probíhající",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n osoba přijala","%n lidé přijali","%n lidí přijalo","%n lidé přijaly"],
    "_%n person declined_::_%n people declined_" : ["%n osoba odmítla","%n lidé odmítli","%n lidí odmítlo","%n lidé odmítli"],
    "_and %n other attachment_::_and %n other attachments_" : ["a %n další příloha","a %n další přílohy","a %n dalších příloh","a %n další přílohy"],
    "With {displayName}" : "S {displayName}",
    "In {conversation}" : "V {conversation}",
    "View attachment" : "Zobrazit přílohu",
    "Join" : "Připojit se",
    "View conversation" : "Zobrazit konverzaci",
    "View event on Calendar" : "Zobrazit událost v Kalendáři",
    "Error while creating the conversation" : "Chyba při vytváření konverzace",
    "Hello, {displayName}" : "Dobrý den, {displayName}",
    "Start meeting now" : "Zahájit schůzku nyní",
    "Give your meeting a title" : "Dejte své schůzce název",
    "Create and copy link" : "Vytvořit a zkopírovat odkaz",
    "Create a new conversation" : "Vytvořit novou konverzaci",
    "Join open conversations" : "Přidat se do všem přístupných konverzací",
    "Call a phone number" : "Vytočit telefonní číslo",
    "Scroll backward" : "Posunout zpět",
    "Scroll forward" : "Posunout vpřed",
    "Schedule meetings" : "Naplánovat schůze",
    "You don't have any upcoming meetings" : "Nemáte žádné nadcházející schůzky",
    "Open calendar" : "Otevřít kalendář",
    "Unread mentions" : "Označit zmínění jako nepřečtená",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Zprávy, ve kterých jste byli zmíněni se zobrazí zde. Lidi můžete zmiňovat zadáním @ (zavináč), následovaného jejich jménem",
    "Upcoming reminders" : "Nadcházející připomínky",
    "Message reminders" : "Připomínky zprávy",
    "Set a reminder on a message to be notified" : "Nastavte si připomínku ohledně zprávy a buďte tak na ni upozorněni",
    "Start a group conversation" : "Zahájit skupinovou konverzaci",
    "Create conversation" : "Vytvořit konverzaci",
    "Enter your name" : "Zadejte své jméno",
    "Submit name and join" : "Odeslat jméno a připojit se",
    "Do you already have an account?" : "Už máte účet?",
    "Log in" : "Přihlásit se",
    "Error while verifying uploaded file" : "Chyba při ověřování nahraného souboru",
    "Uploaded file is verified" : "Nahrání souboru je ověřeno",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Formát obsahu jsou hodnoty oddělované čárkami (CSV):<br/>- Řádek se záhlavím je vyžadován a je třeba, aby se shodoval s <samp>\"name\",\"e-mail\"</samp> nebo pouze <samp>\"email\"</samp><br/>- Každou položku na zvlášť řádek (např. <samp>\"Jan Novák\",\"jan@priklad.tld\"</samp>)",
    "Participants added successfully" : "Účastníci úspěšně přidáni",
    "Error while adding participants" : "Chyba při přidávání účastníků",
    "Import a file" : "Naimportovat soubor",
    "Browse" : "Procházet",
    "Verifying uploaded file …" : "Ověřování nahraného souboru …",
    "This might take a moment" : "Toto může chvíli trvat",
    "Send invitations" : "Odeslat pozvánky",
    "_%n invalid email_::_%n invalid emails_" : ["%n neplatný e-mail","%n neplatné e-maily","%n neplatných e-mailů","%n neplatné e-maily"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n e-mail už byl naimportován nebo jde o duplicitu","%n e-maily už byly naimportovány nebo jde o duplicity","%n e-mailů už bylo naimportováno nebo jde o duplicity","%n e-maily už byly naimportovány nebo jde o duplicity"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["Je možné odeslat %n pozvánku","Je možné odeslat %n pozvánky","Je možné odeslat %n pozvánek","Je možné odeslat %n pozvánky"],
    "An error occurred while calling a phone number" : "Došlo k chybě při volání na telefonní číslo",
    "Phone number could not be called: {error}" : "Nepodařilo se zavolat na telefonní číslo: {error}",
    "Phone number could not be called" : "Na telefonní číslo se nepodařilo zavolat",
    "Search participants or phone numbers" : "Hledat účastníky nebo telefonní čísla",
    "Creating the conversation …" : "Vytváření konverzace …",
    "Mark as read" : "Označit jako přečtené",
    "Mark as unread" : "Označit jako nepřečtené",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Add to favorites" : "Přidat do oblíbených",
    "Unarchive conversation" : "Zrušit archivaci konverzace",
    "Ignore \"Do not disturb\"" : "Ignorovat „Nevyrušovat“",
    "You need to promote a new moderator before you can leave the conversation." : "Než budete moci konverzaci opustit, je třeba předat někomu roli moderátora.",
    "Conversation actions" : "Akce konverzace",
    "Notify about calls" : "Upozorňovat na hovory",
    "Hide message text" : "Skrýt text zprávy",
    "Pending invitations" : "Čekající pozvánky",
    "Join conversations from other servers" : "Připojit se ke konverzacím z ostatních serverů",
    "From {user} at {remoteServer}" : "Od {user} v {remoteServer}",
    "Decline invitation" : "Odmítnout pozvání",
    "Accept invitation" : "Přijmout pozvání",
    "No pending invitations" : "Žádné čekající pozvánky",
    "Home" : "Domů",
    "Unread" : "Nastavit jako nepřečtené",
    "Mentions" : "Zmínění",
    "Meetings" : "Schůze",
    "Alphabetically" : "Abecedně",
    "No followed threads" : "Žádná sledovaná vlákna",
    "No matches found" : "Nenalezeny žádné shody",
    "No conversations found" : "Nenalezena žádná konverzace",
    "You have no archived conversations." : "Nemáte žádné archivované konverzace.",
    "Subscribe to an existing thread or start your own." : "Přihlaste se k odběru stávajícího vlákna nebo zahajte své vlastní.",
    "You have no unread mentions." : "Nemáte žádná nepřečtená zmínění.",
    "You have no unread messages." : "Nemáte žádné nepřečtené zprávy.",
    "An error occurred while performing the search" : "Došlo k chybě při provádění hledání",
    "Conversation list" : "Seznam konverzace",
    "Filter conversations by" : "Filtrovat konverzaci podle",
    "Unread messages" : "Nepřečtené zprávy",
    "Meeting conversations" : "Konverzace schůzky",
    "Clear filters" : "Vyčistit filtry",
    "New personal note" : "Nová osobní poznámka",
    "Back to conversations" : "Zpět na konverzace",
    "Archived conversations" : "Archivované konverzace",
    "Threads" : "Vláken",
    "Clear filter" : "Vyčistit filtr",
    "Show more threads" : "Zobrazit více vláken",
    "App settings" : "Nastavení aplikace",
    "Users" : "Uživatelé",
    "Groups" : "Skupiny",
    "Teams" : "Týmy",
    "Federated users" : "Federovaní uživatelé",
    "New private conversation" : "Nová soukromá konverzace",
    "Other sources" : "Ostatní zdroje",
    "Open conversations" : "Otevřít konverzace",
    "No search results" : "Nic nenalezeno",
    "Users, groups and teams" : "Uživatelé, skupiny a týmy",
    "Users and groups" : "Uživatelé a skupiny",
    "Users and teams" : "Uživatelé a týmy",
    "Groups and teams" : "Skupiny a týmy",
    "New group conversation" : "Nová skupinová konverzace",
    "The meeting will start soon" : "Schůzka brzy začne",
    "This meeting is scheduled for {startTime}" : "Tato schůzka je naplánována na {startTime}",
    "You are currently waiting in the lobby" : "V tuto chvíli se nacházíte v čekárně",
    "Enable noise suppression" : "Zapnout potlačování hluku",
    "Reduce background noises for better voice quality" : "Omezit hluk na pozadí pro lepší kvalitu hlasu",
    "Enable echo cancellation" : "Zapnout potlačování ozvěn",
    "Minimize echo effect from own surrounding" : "Minimalizovat ozvěnu ze svého okolí",
    "Enable auto gain control" : "Zapnout automatickou regulaci zesílení",
    "Dynamically adjust microphone volume for consistent level" : "Dynamicky uzpůsobí zesílení mikrofonu, aby snímal pořád stejně hlasitě",
    "Select microphone" : "Vyberte mikrofon",
    "No microphone available" : "Není k dispozici žádný mikrofon",
    "Select speaker" : "Vybrat reproduktor",
    "No speaker available" : "Není k dispozici žádný reproduktor",
    "Select camera" : "Vyberte kameru",
    "No camera available" : "Není k dispozici žádná kamera",
    "Select a device" : "Vyberte zařízení",
    "Playing …" : "Přehrávání …",
    "Test speakers" : "Vyzkoušet reproduktory",
    "Test" : "Vyzkoušet",
    "Devices" : "Zařízení",
    "Backgrounds" : "Pozadí",
    "No audio" : "Žádný zvuk",
    "No camera" : "Žádná kamera",
    "Display video as you will see it (mirrored)" : "Zobrazit video tak, jak byste ho viděli vy (zrcadlené)",
    "Display video as others will see it" : "Zobrazit si video tak, jako ho uvidí ostatní",
    "Calls are not supported in your browser" : "Vámi používaný prohlížeč nepodporuje volání",
    "Access to microphone is only possible with HTTPS" : "Přístup k mikrofonu je možný pouze přes HTTPS",
    "Access to microphone was denied" : "Přístup k mikrofonu byl odepřen",
    "Error while accessing microphone" : "Chyba při přístupu k mikrofonu",
    "Access to camera is only possible with HTTPS" : "Přístup ke kameře je možný pouze přes HTTPS",
    "The call is being recorded." : "Hovor je nahráván.",
    "The call might be recorded." : "Hovor může být nahráván.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Nahrávka může obsahovat váš hlas, obraz z kamery a sdílení obrazovky. K hovoru se budete moci připojit až po odsouhlasení.",
    "Give consent to the recording of this call" : "Udělit souhlas s nahráváním tohoto hovoru",
    "Show more info" : "Zobrazit další informace",
    "Audio is not available" : "Zvuk není k dispozici",
    "Video is not available" : "Video není k dispozici",
    "Start recording immediately with the call" : "Zahájit nahrávání bezprostředně po zahájení hovoru",
    "Notify all participants about this call" : "Upozornit všechny účastníky na tento hovor",
    "Apply settings" : "Uplatnit nastavení",
    "Select virtual office background" : "Vybrat pozadí virtuální kanceláře",
    "Select virtual home background" : "Vybrat pozadí virtuálního domova",
    "Select virtual abstract background" : "Vybrat virtuální abstraktní ppozadí",
    "Select virtual beach background" : "Vybrat pozadí virtuální pláže",
    "Select virtual park background" : "Vybrat pozadí virtuálního parku",
    "Select virtual theater background" : "Vybrat pozadí virtuálního divadla",
    "Select virtual library background" : "Vybrat pozadí virtuální knihovny",
    "Select virtual space station background" : "Vybrat pozadí virtuální vesmírné stanice",
    "Error while uploading the file" : "Chyba při nahrávání souboru",
    "Select a file" : "Vybrat soubor",
    "Invalid path selected" : "Vybrán neplatný popis umístění",
    "Select virtual background from file {fileName}" : "Vybrat virtuální pozadí ze souboru {fileName}",
    "Blur" : "Rozmazat",
    "Upload" : "Nahrát",
    "Files" : "Soubory",
    "(editing)" : "(upravováno)",
    "(edited)" : "(upraveno)",
    "The message has expired or has been deleted" : "Platnost této zprávy skončila nebo byla smazána",
    "Cancel quote" : "Zrušit citování",
    "24 hours" : "24 hodin",
    "7 days" : "7 dnů",
    "30 days" : "30 dnů",
    "Until unpin" : "Dokud není připnutí zrušeno",
    "Clear reminder – {timeLocale}" : "Odstranit připomínku – {timeLocale}",
    "Edited by {actor}" : "Upravil(a) {actor}",
    "Pinned by you" : "Připnuto vámi",
    "Pinned by {actor}" : "Připnul/a {actor}",
    "Until {absoluteDate}" : "Do {absoluteDate}",
    "Message text copied to clipboard" : "Text zprávy zkopírován do schránky",
    "Message text could not be copied" : "Text zprávy se nepodařilo zkopírovat",
    "Message forwarded to \"Note to self\"" : "Zpráva přeposlána do „Poznámka pro mne“",
    "Error while forwarding message to \"Note to self\"" : "Chyba při přeposílání do „Poznámka pro mne“",
    "A reminder was successfully removed" : "Připomínka byla úspěšně odebrána",
    "Error occurred when removing a reminder" : "Při odebírání připomínky došlo k chybě",
    "A reminder was successfully set at {datetime}" : "Připomínka byla úspěšně nastavena na {datetime}",
    "Error occurred when creating a reminder" : "Při vytváření připomínky došlo k chybě",
    "Add a reaction to this message" : "Přidat reakce na tuto zprávu",
    "Reply" : "Odpovědět",
    "More actions" : "Další akce",
    "Set reminder" : "Nastavit připomínku",
    "Pin message" : "Připnout zprávu",
    "Unpin message" : "Zrušit připnutí zprávy",
    "Reply privately" : "Odpovědět soukromě",
    "Edit message" : "Upravit zprávu",
    "Copy message" : "Zkopírovat zprávu",
    "Copy message link" : "Zkopírovat odkaz zprávy",
    "Go to file" : "Přejít k souboru",
    "Download file" : "Stáhnout si soubor",
    "Go to thread" : "Přejít na vlákno",
    "Edit thread details" : "Upravit podrobnosti o vláknu",
    "Forward message" : "Přeposlat zprávu",
    "Translate" : "Překládání",
    "Set custom reminder" : "Nastavit uživatelsky určenou připomínku",
    "Keep pinned for" : "Ponechat připnuté po dobu",
    "Set custom period" : "Nastavit uživatelsky určené období",
    "Close reactions menu" : "Zavřít nabídku reakcí",
    "React with {emoji}" : "Zareagovat {emoji}",
    "React with another emoji" : "Zareagovat jinou emotikonou",
    "Choose a conversation to forward the selected message." : "Zvolte konverzaci do které označenou zprávu odeslat.",
    "Error while forwarding message" : "Chyba při přeposílání zprávy",
    "The message has been forwarded to {selectedConversationName}" : "Zpráva byla přeposlána do {selectedConversationName}",
    "Dismiss" : "Zavřít",
    "Go to conversation" : "Přejít do konverzace",
    "Detect language" : "Zjistit jazyk",
    "The message could not be translated" : "Zprávu se nepodařilo přeložit",
    "Translation copied to clipboard" : "Překlad zkopírován do schránky",
    "Translation could not be copied" : "Překlad se nepodařilo zkopírovat",
    "Translate message" : "Přeložit zprávu",
    "Source language to translate from" : "Zdrojový jazyk, ze kterého přeložit",
    "Translate from" : "Přeložit z",
    "Target language to translate into" : "Cílový jazyk, do kterého přeložit",
    "Translate to" : "Přeložit do",
    "Translating" : "Překládá se",
    "Copy translated text" : "Zkopírovat přeložený text",
    "Error when scheduling the message" : "Chyba při plánování této zprávy",
    "Reschedule" : "Přeplánovat",
    "Send now" : "Odeslat nyní",
    "Choose a time" : "Zvolit čas",
    "Send at custom time" : "Odeslat v uživatelsky určený čas",
    "Will be sent without notification" : "Bude odesláno bez notifikace",
    "Message read by everyone who shares their reading status" : "Všichni, kteří sdílejí oznámení o přečtení, si zprávu přečetli",
    "Message sent" : "Zpráva odeslána",
    "Sent without notification" : "Odeslat bez oznámení",
    "Deleting message" : "Mazání zprávy",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Zpráva úspěšně smazána, ale je nastavený bot nebo Matterbridge, takže mohla už být odeslána do jiných služeb",
    "Message deleted successfully" : "Zpráva úspěšně smazána",
    "Message could not be deleted because it is too old" : "Zpráva nemohla být smazána, protože je příliš stará",
    "Only normal chat messages can be deleted" : "Pouze normální zprávy mohou být smazány",
    "An error occurred while deleting the message" : "Při mazání zprávy došlo k chybě",
    "Pinned" : "Připnuté",
    "Your browser does not support playing audio files" : "Vámi využívaný prohlížeč nepodporuje přehrávání zvukových souborů",
    "Contact" : "Kontakt",
    "{stack} in {board}" : "{stack} v {board}",
    "Deck Card" : "Karta aplikace Deck",
    "Remove {fileName}" : "Odebrat {fileName}",
    "Open this location in OpenStreetMap" : "Otevřít toto umístění v OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n odpověď","%n odpovědi","%n odpovědí","%n odpovědi"],
    "Sending message" : "Odesílání zprávy",
    "Failed to send the message. Click to try again" : "Odeslání zprávy se nezdařilo. Klikněte pro další pokus",
    "Not enough free space to upload file" : "Pro odeslání souboru není dostatek volného místa",
    "You cannot send messages to this conversation at the moment" : "Nyní není možné do této konverzace posílat zprávy",
    "Could not update the message" : "Nepodařilo se zaktualizovat zprávu",
    "Reply to thread \"{threadTitle}\"" : "Odpovědět na vlákno „{threadTitle}“",
    "_You voted • %n vote_::_You voted • %n votes_" : ["Hlasovali jste • %n hlas","Hlasovali jste • %n hlasy","Hlasovali jste • %n hlasů","Hlasovali jste • %n hlasy"],
    "You voted" : "Hlasovali jste",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["Kliknutím hlasujte • %n hlas","Kliknutím hlasujte • %n hlasy","Kliknutím hlasujte • %n hlasů","Kliknutím hlasujte • %n hlasy"],
    "Click to vote" : "Kliknutím hlasujte",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Koncept ankety • %n volba","Koncept ankety • %n volby","Koncept ankety • %n voleb","Koncept ankety • %n volby"],
    "_%n vote_::_%n votes_" : ["%n hlas","%n hlasy","%n hlasů","%n hlasy"],
    "Edit poll draft" : "Upravit koncept ankety",
    "Delete poll draft" : "Smazat koncept ankety",
    "Open poll" : "Otevřít anketu",
    "Closed poll" : "Uzavřená anketa",
    "See results" : "Zobrazit výsledky",
    "Reactions" : "Reakce",
    "No permission to post reactions in this conversation" : "Nemáte oprávnění reagovat do této konverzace",
    "and {participant}" : "přidat {participant}",
    "_and %n other participant_::_and %n other participants_" : ["a %n další účastník","a %n další účastníci","a %n dalších účastníků","a %n další účastníci"],
    "Show all reactions" : "Zobrazit veškeré reakce",
    "Add more reactions" : "Přidat další reakce",
    "Show or collapse system messages" : "Zobrazit nebo sbalit systémové zprávy",
    "No messages" : "Žádné zprávy",
    "All messages have expired or have been deleted." : "Platnost veškerých zpráv skončila nebo byly smazány.",
    "Generate summary with AI" : "Vytvořit shrnutí pomocí AI",
    "{author} (pinned by you)" : "{author} (připnuto vámi)",
    "{author} (pinned by {actor})" : "{author} (připnul/a {actor})",
    "Unpin" : "Uvolnit",
    "Cancel search" : "Zrušit hledání",
    "Add a phone number" : "Přidat telefonní číslo",
    "Error: A password is required to create the conversation." : "Chyba: pro vytvoření konverzace je zapotřebí hesla.",
    "All set, the conversation \"{conversationName}\" was created." : "Vše hotovo, konverzace „{conversationName}“ byla vytvořena.",
    "Create a new group conversation" : "Vytvořit novou skupinovou konverzaci",
    "Add participants" : "Přidat účastníky",
    "Maximum length exceeded ({maxlength} characters)" : "Překročena nejvyšší umožněná délka ({maxlength} znaků)",
    "Conversation type" : "Typ konverzace",
    "Conversation visibility" : "Viditelnost konverzace",
    "Allow guests to join via link" : "Umožnit hostům, připojit se přes odkaz.",
    "Enter password" : "Zadejte heslo",
    "This conversation has been locked" : "Tato konverzace byla uzamčena",
    "No permission to post messages in this conversation" : "Nemáte oprávnění posílat zprávy do této konverzace",
    "Joining conversation …" : "Připojování ke konverzaci …",
    "Write a message without notification" : "Napsat zprávu bez oznámení",
    "Create a thread silently" : "Vytvořit vlákno, ale neodesílat o tom notifikaci",
    "Create a thread" : "Vytvořit vlákno",
    "Send message silently" : "Poslat zprávu bez upozornění",
    "Send message" : "Poslat zprávu",
    "Send without notification" : "Odeslat bez upozornění",
    "The participant will not be notified about new messages" : "Účastník nebude upozorňován na nové zprávy",
    "Participants will not be notified about new messages" : "Účastníci nebudou upozorňováni na nové zprávy",
    "Message will be sent {datetimeString}" : "Zpráva bude odeslána v {datetimeString}",
    "Thread title is required" : "Je třeba zadat název vlákna",
    "Message text is required" : "Je zapotřebí textu zprávy",
    "The message could not be edited" : "Zprávu nebylo možné upravit",
    "File to share" : "Soubor ke sdílení",
    "File upload is not available in this conversation" : "V této konverzaci není nahrání souboru k dispozici",
    "Message was successfully scheduled" : "Zpráva byla úspěšně naplánována",
    "Add emoji" : "Přidat emoji",
    "Adding a mention will only notify users who did not read the message." : "Přidávání zmínění upozorní pouze uživatele, kteří si zprávu ještě nepřečetli.",
    "Thread title" : "Název vlákna",
    "Send later" : "Odeslat později",
    "Show scheduled messages" : "Zobrazit naplánované zprávy",
    "Cancel editing" : "Zrušit upravování",
    "Schedule message" : "Naplánovat zprávu",
    "{user} is out of office and might not respond." : "{user} je mimo kancelář a může se stát, že neodpoví.",
    "Absence period: {startDate} - {endDate}" : "Období nepřítomnosti: {startDate} - {endDate}",
    "Replacement:" : "Nahrazení:",
    "Share from {nextcloud}" : "Nasdílet z {nextcloud}",
    "Share from Files" : "Sdílet ze Souborů",
    "Share files to the conversation" : "Sdílet soubory do konverzace",
    "Upload from device" : "Nahrát ze zařízení",
    "Create new poll" : "Vytvořit novou anketu",
    "Smart picker" : "Inteligentní výběr",
    "Record voice message" : "Nahrát hlasovou zprávu",
    "End recording and send" : "Ukončit pořizování nahrávky a odeslat",
    "Dismiss recording" : "Zahodit nahrávku",
    "Access to the microphone was denied" : "Přístup k mikrofonu byl odepřen",
    "Microphone either not available or disabled in settings" : "Mikrofon buď není k dispozici nebo je vypnutý v nastaveních",
    "Error while recording audio" : "Chyba při pořizování zvukového záznamu",
    "Voice message {time} ({conversation})" : "Hlasová zpráva {time} ({conversation})",
    "Generating summary of unread messages …" : "Vytváření shrnutí nepřečtených zpráv …",
    "Summary is AI generated and might contain mistakes" : "Shrnutí je vytvářeno AI a může obsahovat chyby",
    "Error occurred during a summary generation" : "Při vytváření shrnutí došlo k chybě",
    "New file" : "Nový soubor",
    "Blank" : "Prázdný",
    "Error while creating file" : "Chyba při vytváření souboru",
    "Create and share a new file" : "Vytvořit a nasdílet nový soubor",
    "Name of the new file" : "Název pro nový soubor",
    "Create file" : "Vytvořit soubor",
    "Someone is typing …" : "Někdo píše …",
    "{user1} is typing …" : "{user1} píše …",
    "{user1} and {user2} are typing …" : "{user1} a {user2} píší …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} a {user3} píší …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} a %n další píše …","{user1}, {user2}, {user3} a %n další píší …","{user1}, {user2}, {user3} a %n dalších píše …","{user1}, {user2}, {user3} a %n další píší …"],
    "Add more files" : "Přidat další soubory",
    "Send" : "Odeslat",
    "In this conversation <strong>{user}</strong> can:" : "V této konverzaci <strong>{user}</strong> může:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Upravit výchozí oprávnění pro účastníky v <strong>{conversationName}</strong>",
    "Start a call" : "Zahájit hovor",
    "Skip the lobby" : "Přeskočit čekárnu",
    "Can post messages" : "Může posílat zprávy",
    "Can post messages and reactions" : "Může posílat zprávy a reakce",
    "Can add reactions" : "Může přidávat reakce",
    "Enable the microphone" : "Zapnout mikrofon",
    "Enable the camera" : "Zapnout kameru",
    "Share the screen" : "Sdílet obsah obrazovky",
    "Update permissions" : "Aktualizovat oprávnění",
    "Updating permissions" : "Aktualizují se oprávnění",
    "No poll drafts" : "Žádné koncepty anket",
    "There is no poll drafts yet saved for this conversation" : "Pro tuto konverzaci zatím nejsou žádné koncepty ankety",
    "Create poll in {name}" : "Vytvořit anketu v {name}",
    "Create poll" : "Vytvořit anketu",
    "Error while importing poll" : "Chyba při importování ankety",
    "Question" : "Otázka",
    "Ask a question" : "Položit dotaz",
    "Import draft from file" : "Naimportovat koncept ze souboru",
    "Answers" : "Odpovědi",
    "Answer {option}" : "Odpověď {option}",
    "Delete poll option" : "Smazat volbu ankety",
    "Add answer" : "Přidat odpověď",
    "Settings" : "Nastavení",
    "Anonymous poll" : "Anonymní anketa",
    "Multiple answers" : "Vícero odpovědí",
    "Save as draft" : "Uložit jako koncept",
    "Export draft to file" : "Exportovat koncept do souboru",
    "_Final results • %n vote_::_Final results • %n votes_" : ["Konečné výsledky • %n hlas","Konečné výsledky • %n hlasy","Konečné výsledky • %n hlasů","Konečné výsledky • %n hlasy"],
    "Your vote is anonymous" : "Vaše hlasování je anonymní",
    "You voted for this option" : "Hlasovali jste pro tuto možnost",
    "End poll" : "Ukončit anketu",
    "Change your vote" : "Změňte svůj hlas",
    "Withdraw vote" : "Vzít hlasování zpět",
    "Results" : "Výsledky",
    "Voted participants" : "Účastníci, kteří odvolili",
    "Send a message to \"{roomName}\"" : "Poslat zprávu do „{roomName}“",
    "Hide list of participants" : "Skrýt seznam účastníků",
    "Show list of participants" : "Zobrazit seznam účastníků",
    "Assistance requested in {roomName}" : "Vyžádána asistence v {roomName}",
    "The message was sent to \"{roomName}\"" : "Zpráva byla odeslána do „{roomName}",
    "Dismiss request for assistance" : "Zahodit požadavek o asistenci",
    "Send message to room" : "Odeslat zprávu do místnosti",
    "Back to main room" : "Zpět do hlavní místnosti",
    "Back to your room" : "Zpátky do vaší místnosti",
    "Message all rooms" : "Poslat zprávu do všech místností",
    "Start session" : "Zahájení relace",
    "Start a call before you start a breakout room session" : "Zahajte hovor předtím, než spustíte relaci přestávkové místnosti",
    "Stop session" : "Ukončení relace",
    "The message was sent to all breakout rooms" : "Zpráva byla zaslána do všech přestávkových místností",
    "Send a message to all breakout rooms" : "Poslat zprávu do všech přestávkových místností",
    "Breakout rooms are not started" : "Přestávkové místnosti nejsou spuštěné",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Hovory bez podpůrné vrstvy pro vysoký výkon mohou způsobovat problémy s připojením k Internetu a vytěžovat zařízení. {linkstart}Zjistěte více{linkend}",
    "Talk setup incomplete" : "Neúplné nastavení Talk",
    "Disable lobby" : "Zavřít čekárnu",
    "Settings for participant \"{user}\"" : "Nastavení pro účastníka „{user}“",
    "Participant \"{user}\"" : "Účastník „{user}“",
    "moderator" : "moderátor",
    "bot" : "bot",
    "guest" : "host",
    "Ringing …" : "Vyzvánění",
    "Call rejected" : "Hovor odmítnut",
    "{time} talking …" : "{time} mluvení …",
    "{time} talking time" : "{time} doba mluvení",
    "Raised their hand" : "Hlásí se",
    "Joined with video" : "Připojen(a) s obrazem",
    "Joined via phone" : "Připojen(a) telefonem",
    "Joined with audio" : "Připojen(a) se zvukem",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Je třeba, aby délka textu byla kratší nebo rovna {maxLength} znaků. Váš stávající text je dlouhý  {charactersCount} znaků.",
    "Remove group and members" : "Odebrat skupinu a její členy",
    "Remove team and members" : "Odebrat tým a uživatele",
    "Remove participant" : "Odebrat účastníka",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Opravdu chcete skupinu „{displayName}“ a její členy odebrat z této konverzace?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Opravdu chcete tým „{displayName}“ a jeho členy odebrat z této konverzace?",
    "Do you really want to remove {displayName} from this conversation?" : "Opravdu chcete {displayName} odebrat z této konverzace?",
    "Notification was sent to {displayName}" : "Upozornění bylo odesláno uživateli {displayName}",
    "Could not send notification to {displayName}" : "Nedaří se odeslat upozornění uživateli {displayName}",
    "Permissions granted to {displayName}" : "Oprávnění uděleno pro {displayName}",
    "Could not modify permissions for {displayName}" : "Nedaří se upravit oprávnění uživateli {displayName}",
    "Permissions removed for {displayName}" : "Oprávnění odebrána uživateli {displayName}",
    "Permissions set to default for {displayName}" : "Oprávnění pro uživatele {displayName} nastavena na výchozí hodnoty",
    "Phone number could not be hung up" : "Hovor na telefonní číslo se nepodařilo zavěsit",
    "Phone number could not be put on hold" : "Hovor na telefonní číslo se nepodařilo pozastavit",
    "Phone number could not be muted" : "Hovor na telefonní číslo se nepodařilo ztlumit",
    "Phone number could not be unmuted" : "Nepodařilo se zrušit ztlumení hovoru na telefonní číslo",
    "DTMF message could not be sent" : "DTMF zprávu se nepodařilo odeslat",
    "Phone number copied to clipboard" : "Telefonní číslo zkopírováno do schránky",
    "Phone number could not be copied" : "Telefonní číslo se nepodařilo zkopírovat",
    "in the lobby" : "v čekárně",
    "Dial out phone" : "Zavolat na telefon",
    "Hang up phone" : "Zavěsit telefon",
    "Move back to lobby" : "Přesunout zpět do čekárny",
    "Move to conversation" : "Přesunout do konverzace",
    "Dial-in PIN" : "PIN kód pro dovolání se",
    "Demote from moderator" : "Odebrat práva moderátora",
    "Promote to moderator" : "Udělit práva moderátora",
    "Resend invitation" : "Znovu poslat pozvánku",
    "Send call notification" : "Odeslat upozornění na hovor",
    "Dial out phone number" : "Telefonní číslo, na které zavolat",
    "Resume call for phone number" : "Pokračovat v hovoru s telefonním číslem",
    "Put phone number on hold" : "Pozastavit hovor s telefonním číslem",
    "Unmute phone number" : "Zrušit ztlumení telefonního čísla",
    "Mute phone number" : "Ztlumit z telefonního čísla",
    "Copy phone number" : "Zkopírovat telefonní číslo",
    "Reset custom permissions" : "Vrátit uživatelsky určená oprávnění na výchozí hodnoty",
    "Grant all permissions" : "Udělit veškerá oprávnění",
    "Remove all permissions" : "Odebrat veškerá oprávnění",
    "Also ban from this conversation" : "Také vyloučit z této konverzace",
    "Internal note (reason to ban)" : "Interní poznámka (důvod pro vyloučení)",
    "Remove" : "Odebrat",
    "Permissions modified for {displayName}" : "Oprávnění upravena uživateli {displayName}",
    "Add users, groups or teams" : "Přidat uživatele, skupiny nebo týmy",
    "Add users or groups" : "Přidat uživatele nebo skupiny",
    "Add users or teams" : "Přidat uživatele nebo týmy",
    "Add users" : "Přidat uživatele",
    "Add groups or teams" : "Přidat skupiny nebo týmy",
    "Add groups" : "Přidat skupiny",
    "Add teams" : "Přidat týmy",
    "Add other sources" : "Přidat další zdroje",
    "Add emails" : "Přidat e-maily",
    "Integrations" : "Napojení",
    "Add federated users" : "Přidat federované uživatele",
    "Searching …" : "Hledání …",
    "Search for more users" : "Hledat další uživatele",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Účastníky je možné vyhledávat nebo přidávat prostřednictvím jména, e-mailu nebo identifikátoru v rámci federovaného cloudu",
    "Search or add participants" : "Vyhledat nebo přidat účastníky",
    "Invitation was sent to {actorId}" : "Odeslána pozvánka pro {actorId}",
    "An error occurred while adding the participants" : "Při přidávání účastníků došlo k chybě",
    "A new group conversation with selected participant will be created" : "Bude vytvořena nová skupinová konverzace s vybraným účastníkem",
    "Participants" : "Účastníci",
    "Pinned by a deleted user" : "Připnuto smazaným uživatelem",
    "Participants ({count})" : "Účastníci ({count})",
    "Open chat" : "Otevřít chat",
    "You have new unread messages in the chat." : "Máte nové nepřečtené zprávy v chatu.",
    "You have been mentioned in the chat." : "Byli jste zmíněni v chatu.",
    "Search messages" : "Hledat zprávy",
    "Chat" : "Chat",
    "Details" : "Podrobnosti",
    "Shared items" : "Sdílené položky",
    "Search in {name}" : "Hledat v {name}",
    "Threads in {name}" : "Vlákna v {name}",
    "{actor} in {conversation}" : "{actor} v {conversation}",
    "Search messages …" : "Hledat ve zprávách …",
    "Search options" : "Možnosti vyhledávání",
    "From User" : "Od uživatele",
    "Since" : "Už od",
    "Until" : "Do",
    "No results found" : "Nic nenalezeno",
    "Load more results" : "Načíst další výsledky",
    "Recent threads" : "Nedávná vlákna",
    "Projects" : "Projekty",
    "No shared items" : "Žádné sdílené položky",
    "Thread notifications" : "Notifikace ohledně vlákna",
    "Thread actions" : "Akce ohledně vlákna",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Odkaz na konverzaci",
    "No open conversations found" : "Nenalezeny žádné všem přístupné konverzace",
    "Either there are no open conversations or you joined all of them." : "Buď zde nejsou žádné všem přístupné konverzace, nebo už jste se přidali do všech z nich.",
    "Check spelling or use complete words." : "Zkontrolovat pravopis nebo doplňovat slova.",
    "Search conversations or users" : "Hledat konverzace nebo uživatele",
    "Select conversation" : "Vybrat konverzaci",
    "Number length is not valid" : "Délka čísla není platná",
    "Region code is not valid" : "Kód oblasti není platný",
    "Number length is too short" : "Číslo je příliš krátké",
    "Number length is too long" : "Číslo je příliš dlouhé",
    "Number is not valid" : "Číslo není platné",
    "Phone numbers" : "Telefonní čísla",
    "Display name: {name}" : "Zobrazované jméno: {name}",
    "Edit display name" : "Upravit zobrazovaný název",
    "Display name (required)" : "Zobrazované jméno (vyžadováno)",
    "Save name" : "Uložit název",
    "I picked message bubbles" : "Vybral/a jsem bubliny zpráv",
    "I picked the list style" : "Vybral jsem si styl seznamu",
    "Error while setting personal setting" : "Chyba při nastavování osobních nastavení",
    "Error while saving sounds setting" : "Chyba při ukládání nastavení zvuku",
    "Compact conversations list" : "Zhuštěný seznam konverzací",
    "Chat appearance" : "Vzhled chatu",
    "Messages list" : "Seznam zpráv",
    "Message bubbles" : "Bubliny zpráv",
    "Play sounds when participants join or leave a call" : "Přehrát zvuky oznámení když se účastníci připojí nebo odpojí",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Z důvodu technických omezení, zavedených jejich výrobcem, není  v současnosti na zařízeních iPad a iPhone k dispozici",
    "Notification settings" : "Nastavení upozorňování",
    "Sounds for chat and call notifications" : "Zvuky pro notifikace na chat a volání",
    "Invalid language ({languageId})" : "Neplatný jazyk ({languageId})",
    "Default language" : "Výchozí jazyk",
    "Default language ({languageName})" : "Výchozí jazyk ({languageName})",
    "Error when trying to load the available live translation languages" : "Chyba při pokusu o načtení jazyků, dostupných pro průběžný překlad",
    "Error when trying to set live translation language" : "Chyba při pokusu o nastavení jazyka průběžného překladu",
    "Set language used to show the transcriptions" : "Nastavit jazyk použitý pro zobrazení přepisu do textu",
    "Select location for attachments" : "Vyberte umístění pro přílohy",
    "Error while setting attachment folder" : "Chyba při nastavování složky pro přílohy",
    "Error while setting read status privacy" : "Chyba při nastavování oznámení o přečtení",
    "Error while setting typing status privacy" : "Chyba při nastavování soukromí pro stav psaní",
    "Error while setting default media state" : "Chyba při nastavování výchozího stavu média",
    "Turn camera and microphone off by default" : "Ve výchozím stavu vypnout kameru a mikrofon",
    "Blur camera background by default" : "Rozmazávat pozadí záběru z kamery už ve výchozím stavu",
    "Skip device preview before joining a call" : "Před připojením se k hovoru přeskočit náhled ze zařízení",
    "Appearance & Sounds" : "Vzhled a zvuky",
    "Privacy" : "Soukromí",
    "Send read receipts" : "Odeslat potvrzení o přečtení",
    "When off, all read statuses will be hidden" : "Pokud vypnuto, všechny přečtené stavy budou skryté",
    "Share typing status" : "Sdílet stav psaní",
    "When off, all typing indicators will be hidden" : "Pokud vypnuto, veškeré indikátory psaní budou skryté",
    "Attachments folder" : "Složka s přílohami",
    "Toggle full screen" : "Vyp/zap. zobrazení na celou obrazovku",
    "Return to Home screen" : "Vrátit se na domovskou obrazovku",
    "Search" : "Hledat",
    "Shortcuts while in a chat" : "Zkratky při používání chatu",
    "Focus the chat input" : "Zaměřit okno psaní chatu",
    "Unfocus the chat input to use shortcuts" : "Abyste mohli použít klávesové zkratky, je třeba zrušit zaměření psaní v chatu",
    "Edit your last message" : "Upravit svou poslední zprávu",
    "Shortcuts while in a call" : "Klávesové zkratky při volání",
    "Camera on and off" : "Kamera zapnout a vypnout",
    "Microphone on and off" : "Mikrofon zapnout a vypnout",
    "Raise or lower hand" : "Hlásit se nebo přestat",
    "Push to talk or push to mute" : "Stisknout a držet pro mluvení či naopak pro odmlčení se - podle předchozího stavu mikrofonu",
    "Zoom-in / zoom-out a screen share" : "Přiblížit/oddálit sdílení obrazovky",
    "Mouse wheel" : "Kolečko myši",
    "Start call silently" : "Zahájit hovor tiše",
    "Start call" : "Zavolat",
    "End call" : "Ukončit hovor",
    "The server was updated, you cannot start or join a call." : "Server byl zaktualizován – nemůžete zahájit nebo se připojit do volání.",
    "This call has just ended" : "Tento hovor právě skončil",
    "You will be able to join the call only after a moderator starts it." : "K hovoru se budete moci připojit až poté, co ho moderátor zahájí.",
    "End call for everyone" : "Ukončit hovor pro všechny",
    "Starting the recording" : "Zahájit nahrávání",
    "Recording" : "Zaznamenávání",
    "The call has been running for one hour." : "Hovor trvá už hodinu.",
    "Cancel recording start" : "Zrušit zahajování nahrávání",
    "Stop recording" : "Zastavit nahrávání",
    "Send a reaction" : "Poslat reakci",
    "React with {reaction}" : "Zareagovat s {reaction}",
    "All tasks done!" : "Všechny úkoly hotové!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} z %n úkolu","{done} z %n úkolů","{done} z %n úkolů","{done} z %n úkolů"],
    "Add participants to this call" : "Přidat účastníky do tohoto hovoru",
    "_%n participant in call_::_%n participants in call_" : ["%n účastník hovoru","%n účastníci hovoru","%n účastníků hovoru","%n účastníci hovoru"],
    "Scheduled messages" : "Naplánované zprávy",
    "You are not allowed to enable screensharing" : "Nemáte oprávnění zapnout sdílení obsahu vaší obrazovky",
    "No screensharing" : "Obrazovka není sdílena",
    "Screensharing options" : "Možnosti sdílení obrazovky",
    "Enable screensharing" : "Povolit sdílení obrazovky",
    "Bad sent video and screen quality." : "Špatná technická kvalita odesílaného videa a obsahu obrazovky.",
    "Bad sent screen quality." : "Špatná technická kvalita odesílání obsahu obrazovky.",
    "Bad sent video quality." : "Špatná kvalita odesílaného videa.",
    "Bad sent audio, video and screen quality." : "Špatná technická kvalita odesílaného zvuku, videa a obsahu obrazovky.",
    "Bad sent audio and screen quality." : "Špatná technická kvalita odesílaného zvuku a sdílení obsahu obrazovky.",
    "Bad sent audio and video quality." : "Špatná kvalita odesílaného zvuku a videa.",
    "Bad sent audio quality." : "Špatná kvalita odesílaného zvuku.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Vaše připojení k Internetu nebo počítač je zahlcené – vaše řeč může být pro ostatní účastníky nesrozumitelná. Také nemusí vidět obsah vaší obrazovky. Pro zlepšení situace zkuste po dobu sdílení obsahu obrazovky přestat vysílat video či vypnout rozmazání pozadí.",
    "Disable background blur" : "Vypnout rozmazávání pozadí za vámi",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Vaše připojení k Internetu nebo počítač je zahlcené – ostatní účastníci vaši obrazovku možná neuvidí. Pro zlepšení situace zkuste po dobu sdílení obsahu obrazovky přestat vysílat video.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Vaše připojení k Internetu nebo počítač je zahlcené – ostatní účastníci možná obsah vaší obrazovky neuvidí.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Vaše připojení k Internetu nebo počítač je zahlcené – ostatní účastníci vás možná neuvidí.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Vaše připojení k Internetu nebo počítač je zahlcené – vaše řeč může být pro ostatní účastníky nesrozumitelná. Také vás nemusí vidět. Pro zlepšení situace zkuste po dobu sdílení obsahu obrazovky přestat vysílat video či vypnout rozmazání pozadí.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Vaše připojení k Internetu nebo počítač je zahlcené – vaše řeč může být pro ostatní účastníky nesrozumitelná. Také vás nemusí vidět. Pro zlepšení situace zkuste po dobu sdílení obsahu obrazovky přestat vysílat video.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Vaše připojení k Internetu nebo počítač je zahlcené – vaše řeč může být pro ostatní účastníky nesrozumitelná. Také nemusí vidět obsah vaší obrazovky. Pro zlepšení situace zkuste přestat sdílet obsah obrazovky.",
    "Disable screenshare" : "Vypnout sdílení obrazovky",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Vaše připojení k Internetu nebo počítač je zahlcené – vaše řeč může být pro ostatní účastníky nesrozumitelná. Také vás nemusí vidět. Pro zlepšení situace zkuste přestat vysílat video či vypnout rozmazání pozadí.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Vaše připojení k Internetu nebo počítač je zahlcené – vaše řeč může být pro ostatní účastníky nesrozumitelná. Také vás nemusí vidět. Pro zlepšení situace zkuste přestat vysílat video.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Vaše připojení k Internetu nebo počítač je zahlcené – vaše řeč může být pro ostatní účastníky nesrozumitelná.",
    "Screen sharing is not supported by your browser." : "Sdílení obrazovky není vaším prohlížečem podporováno.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Sdílení obrazovky vyžaduje, aby byla stránka načtena přes HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Sdílení obrazovky vyžaduje, aby byla stránka načtena přes HTTPS.",
    "An error occurred while starting screensharing." : "Při zahajování sdílení obrazovky došlo k chybě.",
    "Select virtual background" : "Vybrat virtuální pozadí",
    "Show your screen" : "Zobrazit vaši obrazovku",
    "Stop screensharing" : "Přestat sdílet obrazovku",
    "Mute others" : "Ztlumit ostatní",
    "Start recording" : "Zahájit nahrávání",
    "Set up breakout rooms" : "Nastavit přestávkové místnosti",
    "Download attendance list" : "Stáhnout si seznam účastníků",
    "Open Calendar" : "Otevřít kalendář",
    "Remove participant {name}" : "Odebrat účastníka {name}",
    "Would you like to delete this conversation?" : "Chcete tuto konverzaci smazat?",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["Tato konverzace bude automaticky smazána pro kohokoli po uplynutí %n dne neaktivity.","Tato konverzace bude automaticky smazána pro kohokoli po uplynutí %n dnů neaktivity.","Tato konverzace bude automaticky smazána pro kohokoli po uplynutí %n dnů neaktivity.","Tato konverzace bude automaticky smazána pro kohokoli po uplynutí %n dnů neaktivity."],
    "Are you sure you want to delete this conversation?" : "Opravdu chcete tuto konverzaci smazat?",
    "Delete now" : "Smazat nyní",
    "Keep" : "Ponechat",
    "Open dialpad" : "Otevřít číselník",
    "Select a region" : "Vyberte oblast",
    "Local time: {time}" : "Místní čas: {time}",
    "Scheduled {datetime}" : "Naplánováno {datetime}",
    "Scheduled for {datetime}" : "Naplánováno na {datetime}",
    "Search …" : "Hledat …",
    "Message without mention" : "Zprávy, ve kterých nezmíněno",
    "Mention myself" : "Zmínit sebe sama",
    "Mention everyone" : "Zmínit všechny",
    "Select a conversation" : "Vybrat konverzaci",
    "Select a mode" : "Vyberte režim",
    "You do not have permissions to access this conversation." : "Nemáte oprávnění pro přístup k této konverzaci.",
    "Join a different conversation or start a new one." : "Připojte se k jiné konverzaci, nebo začněte novou.",
    "The conversation does not exist" : "Konverzace neexistuje",
    "Join a conversation or start a new one!" : "Připojte se ke konverzaci nebo zahajte novou",
    "Duplicate session" : "Zduplikovat sezení",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "Tato konverzace byla otevřena v jiném panelu. Stávající verze serveru nepodporuje otevírání konverzace ve vícero panelech.",
    "Creating and joining a conversation with \"{userid}\"" : "Vytváření a vstupování do konverzace s „{userid}“",
    "Join a conversation or start a new one" : "Připojte se ke konverzaci, nebo začněte novou",
    "Error while joining the conversation" : "Chyba při připojování do konverzace",
    "Another user" : "Jiný uživatel",
    "Hey! Are you using the list style or message bubbles?" : "Hej! Používáte styl seznamu nebo bubliny zpráv?",
    "Nextcloud URL" : "URL adresa Nextcloud",
    "Nextcloud user" : "Uživatel Nextcloud",
    "User password" : "Heslo uživatele",
    "Talk conversation" : "Konverzace v Talk",
    "Skip TLS verification" : "Přeskočit ověřování TLS",
    "Matrix server URL" : "URL adresa Matrix serveru",
    "User" : "Uživatel",
    "Matrix channel" : "Matrix kanál",
    "Mattermost server URL" : "URL adresa Mattermost serveru",
    "Mattermost user" : "Uživatel v Mattermost",
    "Team name" : "Název týmu",
    "Channel name" : "Název kanálu",
    "Rocket.Chat server URL" : "URL adresa Rocket.Chat serveru",
    "User name or email address" : "Uživ. jméno nebo e-mail",
    "Rocket.Chat channel" : "Rocket.Chat kanál",
    "Zulip server URL" : "URL adresa Zulip serveru",
    "Bot user name" : "Uživatelské jméno bota",
    "Bot API key" : "Klíč k aplikačnímu program. rozhraní pro bota",
    "Zulip channel" : "Zulip kanál",
    "API token" : "Token do aplikačního program. rozhraní (API)",
    "Slack channel" : "Slack kanál",
    "Server ID or name" : "Identif. nebo název serveru",
    "Channel ID (prefixed with \"ID:\") or name" : "Identif. kanálu (předeslaný „ID:“) nebo název",
    "Channel" : "Kanál",
    "Login" : "Přihlašovací jméno",
    "Chat ID" : "Identif. chatu",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL adresa IRC serveru (např. chat.freenode.net:6667)",
    "Nickname" : "Přezdívka",
    "Connection password" : "Heslo k připojení",
    "IRC channel" : "IRC kanál",
    "Channel password" : "Heslo kanálu",
    "NickServ nickname" : "Přezdívka na NickServ",
    "NickServ password" : "Heslo k NickServ",
    "Use TLS" : "Použít TLS",
    "Use SASL" : "Použít SASL",
    "Tenant ID" : "Identif. nájemce",
    "Client ID" : "Identif. klienta",
    "Team ID" : "Identifikátor týmu",
    "Thread ID" : "Identif. vlákna",
    "XMPP/Jabber server URL" : "URL adresa XMPP/Jabber serveru",
    "MUC server URL" : "URL adresa MUC serveru",
    "Jabber ID" : "Jabber identif.",
    "Pinned messages" : "Připnuté zprávy",
    "Media" : "Média",
    "Polls" : "Ankety",
    "Deck cards" : "Karty aplikace Deck",
    "Voice messages" : "Hlasové zprávy",
    "Locations" : "Polohy",
    "Call recordings" : "Nahrávky hovoru",
    "Audio" : "Zvuk",
    "Show all pinned messages" : "Zobrazit všechny připnuté zprávy",
    "Show all media" : "Zobrazit veškerá média",
    "Show all files" : "Zobrazit všechny soubory",
    "Show all polls" : "Zobrazit veškeré ankety",
    "Show all deck cards" : "Zobrazit všechny karty aplikace Deck",
    "Show all voice messages" : "Zobrazit všechny hlasové zprávy",
    "Show all locations" : "Zobrazit všechny polohy",
    "Show all call recordings" : "Zobrazit veškeré nahrávky hovorů",
    "Show all audio" : "Zobrazit všechno audio",
    "Show all other" : "Zobrazit všechno ostatní",
    "Follow conversation settings" : "Nastavení následování konverzace",
    "Group" : "Skupina",
    "Team" : "Tým",
    "You reconnected to the call" : "Připojili jste se zpět k hovoru",
    "{actor} reconnected to the call" : "{actor} se připojil(a) zpět k hovoru",
    "You added {user0} and {user1}" : "Přidali jste {user0} a {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Přidali jste {user0}, {user1} a %n dalšího účastníka","Přidali jste {user0}, {user1} a %n další účastníky","Přidali jste {user0}, {user1} a %n dalších účastníků","Přidali jste {user0}, {user1} a %n další účastníky"],
    "An administrator added you and {user0}" : "Správce přidal vás a {user0}",
    "{actor} added you and {user0}" : "{actor} přidal(a) vás a {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Správce přidal vás, {user0} a %n dalšího účastníka","Správce přidal vás, {user0} a %n další účastníky","Správce přidal vás, {user0} a %n dalších účastníků","Správce přidal vás, {user0} a %n další účastníky"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} přidal(a) vás, {user0} a %n dalšího účastníka","{actor} přidal(a) vás, {user0} a %n další účastníky","{actor} přidal(a) vás, {user0} a %n dalších účastníků","{actor} přidal(a) vás, {user0} a %n další účastníky"],
    "An administrator added {user0} and {user1}" : "Správce přidal {user0} a {user1}",
    "{actor} added {user0} and {user1}" : "{actor} přidal(a) {user0} a {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Správce přidal {user0}, {user1} a %n dalšího účastníka","Správce přidal {user0}, {user1} a %n další účastníky","Správce přidal {user0}, {user1} a %n dalších účastníků","Správce přidal {user0}, {user1} a %n další účastníky"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} přidal(a) {user0}, {user1} a %n dalšího účastníka","{actor} přidal(a) {user0}, {user1} a %n další účastníky","{actor} přidal(a) {user0}, {user1} a %n dalších účastníků","{actor} přidal(a) {user0}, {user1} a %n další účastníky"],
    "You removed {user0} and {user1}" : "Odebrali jste {user0} a {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Odebrali jste {user0}, {user1} a %n dalšího účastníka","Odebrali jste {user0}, {user1} a %n další účastníky","Odebrali jste {user0}, {user1} a %n dalších účastníků","Odebrali jste {user0}, {user1} a %n další účastníky"],
    "An administrator removed you and {user0}" : "Správce odebral vás „{user0}“",
    "{actor} removed you and {user0}" : "{actor} odebral(a) vás a {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Správce odebral vás, {user0} a %n dalšího účastníka","Správce odebral vás, {user0} a %n další účastníky","Správce odebral vás, {user0} a %n dalších účastníků","Správce odebral vás, {user0} a %n další účastníky"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} odebral(a) vás, {user0} a %n dalšího účastníka","{actor} odebral(a) vás, {user0} a %n další účastníky","{actor} odebral(a) vás, {user0} a %n dalších účastníků","{actor} odebral(a) vás, {user0} a %n další účastníky"],
    "An administrator removed {user0} and {user1}" : "Správce odebral {user0} a {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} odebral(a) {user0} a {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Správce odebral {user0}, {user1} a %n dalšího účastníka","Správce odebral {user0}, {user1} a %n další účastníky","Správce odebral {user0}, {user1} a %n dalších účastníků","Správce odebral {user0}, {user1} a %n další účastníky"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} odebral(a) {user0}, {user1} a %n dalšího účastníka","{actor} odebral(a) {user0}, {user1} a %n další účastníky","{actor} odebral(a) {user0}, {user1} a %n dalších účastníků","{actor} odebral(a) {user0}, {user1} a %n další účastníky"],
    "You and {user0} joined the call" : "Vy a {user0} jste se připojili k hovoru",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Vy, {user0} a %n další účastník jste se připojili k hovoru","Vy, {user0} a %n další účastníci jste se připojili k hovoru","Vy, {user0} a %n dalších účastníků se připojilo k hovoru","Vy, {user0} a %n další účastníci jste se připojili k hovoru"],
    "{user0} and {user1} joined the call" : "{user0} a {user1} se připojili k hovoru",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} a %n další účastník se připojili k hovoru","{user0}, {user1} a %n další účastníci se připojili k hovoru","{user0}, {user1} a %n dalších účastníků se připojilo k hovoru","{user0}, {user1} a %n další účastníci se připojili k hovoru"],
    "You and {user0} left the call" : "Vy a {user0} jste opustili hovor",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Vy, {user0} a %n další účastník jste opustili hovor","Vy, {user0} a %n další účastníci jste opustili hovor","Vy, {user0} a %n dalších účastníků opustilo hovor","Vy, {user0} a %n další účastníci jste opustili hovor"],
    "{user0} and {user1} left the call" : "{user0} a {user1} opustili hovor",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} a %n další účastník opustili hovor","{user0}, {user1} a %n další účastníci opustil hovor","{user0}, {user1} a %n dalších účastníků opustilo hovor","{user0}, {user1} a %n další účastníci opustil hovor"],
    "You promoted {user0} and {user1} to moderators" : "Přidali jste {user0} a {user1} práva moderátora",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Udělili jste {user0}, {user1} a %n dalšímu účastníkovi práva moderátora","Udělili jste {user0}, {user1} a %n dalším účastníkům práva moderátora","Udělili jste {user0}, {user1} a %n dalším účastníkům práva moderátora","Udělili jste {user0}, {user1} a %n dalším účastníkům práva moderátora"],
    "An administrator promoted you and {user0} to moderators" : "Správce vám a {user0} přidal práva moderátora",
    "{actor} promoted you and {user0} to moderators" : "{actor} vám a {user0} udělila(a) práva moderátora",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Správce udělil vám, {user0} a %n dalšímu účastníkovi práva moderátora","Správce udělil vám, {user0} a %n dalším účastníkům práva moderátora","Správce udělil vám, {user0} a %n dalším účastníkům práva moderátora","Správce udělil vám, {user0} a %n dalším účastníkům práva moderátora"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} udělil vám, {user0} a %n dalšímu účastníkovi práva moderátora","{actor} udělil vám, {user0} a %n dalším účastníkům práva moderátora","{actor} udělil vám, {user0} a %n dalším účastníkům práva moderátora","{actor} udělil vám, {user0} a %n dalším účastníkům práva moderátora"],
    "An administrator promoted {user0} and {user1} to moderators" : "Správce udělil {user0} a {user1} práva moderátorů",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} udělil {user0} a {user1} práva moderátorů",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Správce udělil {user0}, {user1} a %n dalšímu účastníkovi práva moderátora","Správce udělil {user0}, {user1} a %n dalším účastníkům práva moderátora","Správce udělil {user0}, {user1} a %n dalším účastníkům práva moderátora","Správce udělil {user0}, {user1} a %n dalším účastníkům práva moderátora"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} udělil {user0}, {user1} a %n dalšímu účastníkovi práva moderátora","{actor} udělil {user0}, {user1} a %n dalším účastníkům práva moderátora","{actor} udělil {user0}, {user1} a %n dalším účastníkům práva moderátora","{actor} udělil {user0}, {user1} a %n dalším účastníkům práva moderátora"],
    "You demoted {user0} and {user1} from moderators" : "Odebrali jste {user0} a {user1} práva moderátora",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Odebrali jste {user0}, {user1} a %n dalšímu účastníkovi práva moderátora","Odebrali jste {user0}, {user1} a %n dalším účastníkům práva moderátora","Odebrali jste {user0}, {user1} a %n dalším účastníkům práva moderátora","Odebrali jste {user0}, {user1} a %n dalším účastníkům práva moderátora"],
    "An administrator demoted you and {user0} from moderators" : "Správce vám a {user0} odebral práva moderátora",
    "{actor} demoted you and {user0} from moderators" : "{actor} odebral(a) vám a {user0} práva moderátora",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Správce odebral vám, {user0} a %n dalšímu účastníkovi práva moderátora","Správce odebral vám, {user0} a %n dalším účastníkům práva moderátora","Správce odebral vám, {user0} a %n dalším účastníkům práva moderátora","Správce odebral vám, {user0} a %n dalším účastníkům práva moderátora"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} odebral(a) vám, {user0} a %n dalšímu účastníkovi práva moderátora","{actor} odebral(a) vám, {user0} a %n dalším účastníkům práva moderátora","{actor} odebral(a) vám, {user0} a %n dalším účastníkům práva moderátora","{actor} odebral(a) vám, {user0} a %n dalším účastníkům práva moderátora"],
    "An administrator demoted {user0} and {user1} from moderators" : "Správce odebral {user0} a {user1} práva moderátora",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} odebral(a) {user0} a {user1} práva moderátorů",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Správce odebral {user0}, {user1} a %n dalšímu účastníkovi práva moderátora","Správce odebral {user0}, {user1} a %n dalším účastníkům práva moderátora","Správce odebral {user0}, {user1} a %n dalším účastníkům práva moderátora","Správce odebral {user0}, {user1} a %n dalším účastníkům práva moderátora"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} odebral(a {user0}, {user1} a %n dalšímu účastníkovi práva moderátora","{actor} odebral(a {user0}, {user1} a %n dalším účastníkům práva moderátora","{actor} odebral(a {user0}, {user1} a %n dalším účastníkům práva moderátora","{actor} odebral(a {user0}, {user1} a %n dalším účastníkům práva moderátora"],
    "You:" : "Vy:",
    "You: {lastMessage}" : "Vy: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "Server byl zaktualizován.",
    "(edited by you)" : "(upraveno vámi)",
    "(edited by a deleted user)" : "(upraveno smazaným uživatelem)",
    "(edited by {moderator})" : "(upravil(a) {moderator})",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Pokoušíte se připojit ke konverzaci zatímco máte aktivní relaci v ní v jiném okně nebo zařízení. Toto Nextcloud Talk zatím nepodporuje. Co chcete udělat?",
    "Leave this page" : "Opustit tuto stránku",
    "Join here" : "Přidat se zde",
    "Deck card has been posted to {conversation}" : "Karta v Deck byla uvedena v {conversation}",
    "An error occurred while posting deck card to conversation" : "Při odesílání karty aplikace Deck došlo k chybě",
    "Post to a conversation" : "Odeslat do konverzace",
    "Post to conversation" : "Odeslat do konverzace",
    "The recording failed. Please contact your administrator." : "Nahrávání se nezdařilo. Obraťte se na svého správce.",
    "Location has been posted to {conversation}" : "Umístění bylo zasláno do {conversation}",
    "An error occurred while posting location to conversation" : "Při odesílání polohy do konverzace došlo k chybě",
    "Share to a conversation" : "Nasdílet do konverzace",
    "Share to conversation" : "Nasdílet do konverzace",
    "In conversation" : "V konverzaci",
    "Search in conversation: {conversation}" : "Hledat v konverzaci: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Četnost vašich požadavků byla pro tuto chvíli omezena ochranou proti útoku zkoušením všech možných hesel",
    "Error while clearing conversation history" : "Chyba při vymazávání historie konverzace",
    "Error occurred while allowing guests" : "Při povolování hostů došlo k chybě",
    "Error occurred while disallowing guests" : "Při zakazování hostů došlo k chybě",
    "Error occurred when restricting the conversation to moderator" : "Při omezování konverzace pouze na moderátora došlo k chybě",
    "Error occurred when opening the conversation to everyone" : "Při otevírání konverzace všem došlo k chybě",
    "Conversation password has been saved" : "Heslo do konverzace bylo uloženo",
    "Conversation password has been removed" : "Heslo do konverzace bylo odebráno",
    "Error occurred while saving conversation password" : "Při ukládání hesla konverzace došlo k chybě",
    "Call recording is starting." : "Nahrávání hovoru se spouští.",
    "Call recording stopped while starting." : "Pořizování nahrávky z hovoru se při spouštění zastavilo.",
    "Call recording stopped. You will be notified once the recording is available." : "Nahrávání hovoru zastaveno. Budete upozorněni jakmile bude nahrávka k dispozici.",
    "Conversation picture set" : "Obrázek konverzace nastaven",
    "Conversation picture deleted" : "Obrázek konverzace smazán",
    "Could not delete the conversation picture" : "Nepodařilo se smazat obrázek konverzace",
    "Could not remove the automatic expiration" : "Nebylo možné odebrat automatické skončení platnosti",
    "Could not post message: {errorMessage}" : "Zprávu se nedaří odeslat: {errorMessage}",
    "Participant is banned successfully" : "Účastní je úspěšně vyloučen",
    "Error while banning the participant" : "Chyba při vylučování účastníka",
    "An error occurred while fetching the participants" : "Došlo k chybě při získávání seznamu účastníků",
    "Could not send invitation to {actorId}" : "Nebylo možné poslat pozvánku pro {actorId}",
    "Invitations sent" : "Pozvánky rozeslány",
    "Error occurred when sending invitations" : "Při rozesílání pozvánek došlo k chybě",
    "Failed to join the conversation." : "Nepodařilo se připojit do konverzace.",
    "An error occurred while creating breakout rooms" : "Došlo k chybě při vytváření přestávkových místností",
    "An error occurred while re-ordering the attendees" : "Při přeuspořádávání účastníků došlo k chybě",
    "An error occurred while deleting breakout rooms" : "Došlo k chybě při mazání přestávkových místností",
    "An error occurred while starting breakout rooms" : "An error occurred while spouštění breakout rooms",
    "An error occurred while stopping breakout rooms" : "Došlo k chybě při zastavování přestávkových místností",
    "An error occurred while sending a message to the breakout rooms" : "Došlo k chybě při posílání zpráv do přestávkových místností",
    "An error occurred while requesting assistance" : "Při žádosti o asistenci došlo k chybě",
    "An error occurred while resetting the request for assistance" : "Při resetování žádosti o asistenci došlo k chybě",
    "An error occurred while joining breakout room" : "Došlo k chybě při připojování se do přestávkové místnosti",
    "Failed to rename the thread" : "Nepodařilo se přejmenovat vlákno",
    "Error fetching upcoming events" : "Chyba při získávání nadcházejících událostí",
    "Error fetching upcoming reminders" : "Chyba při získávání nadcházejících připomínek",
    "An error occurred while accepting an invitation" : "Došlo k chybě při přijímání pozvánky",
    "An error occurred while rejecting an invitation" : "Došlo k chybě při odmítání pozvánky",
    "{guest} (guest)" : "{guest} (host)",
    "Poll draft has been saved" : "Koncept ankety byl uložen",
    "An error occurred while saving the draft" : "Došlo k chybě při ukládání konceptu",
    "An error occurred while submitting your vote" : "Při odesílání vašeho hlasu došlo k chybě",
    "An error occurred while ending the poll" : "Při uzavírání ankety došlo k chybě",
    "An error occurred while deleting the poll draft" : "Došlo k chybě při mazání konceptu ankety",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Anketa „{name}“ byla vytvořena uživatelem {user}. Kliknutím budete hlasovat",
    "Failed to add reaction" : "Nepodařilo se přidat reakci",
    "Failed to remove reaction" : "Nepodařilo se odebrat reakci",
    "The server is in maintenance mode." : "Server se nachází v režimu údržby.",
    "Federated server was updated." : "Federovaný server byl zaktualizován.",
    "Error while uploading file \"{fileName}\"" : "Chyba při nahrávání „{fileName}“",
    "Not enough free space to upload file \"{fileName}\"" : "Nedostatek místa pro nahrání souboru „{fileName}“",
    "You are not allowed to share files" : "Ke sdílení souborů nemáte povolení",
    "Error while sharing file" : "Chyba při sdílení souboru",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Webový prohlížeč, který používáte, není Nextcloud Talk plně podporován. Prosíme použijte nejnovější verzi Mozilla Firefox, Microsoft Edge, Google Chrome, Opera nebo Apple Safari.",
    "_In %n hour_::_In %n hours_" : ["Během %n hodiny","Během %n hodin","Během %n hodin","Během %n hodin"],
    "_%n minute _::_%n minutes_" : ["%n minuta ","%n minuty ","%n minut ","%n minuty "],
    "In {hours} and {minutes}" : "Za {hours} a {minutes}",
    "_In %n minute_::_In %n minutes_" : ["během %n minuty","během %n minut","během %n minut","během %n minut"],
    "Later today – {timeLocale}" : "Později dnes – {timeLocale}",
    "Set time for later today" : "Nastavit čas na později dnes",
    "Tomorrow – {timeLocale}" : "Zítra – {timeLocale}",
    "Set time for tomorrow" : "Nastavit čas na zítra",
    "This weekend – {timeLocale}" : "Tento víkend – {timeLocale}",
    "Set time for this weekend" : "Nastavit čas na tento víkend",
    "Next week – {timeLocale}" : "Příští týden – {timeLocale}",
    "Set time for next week" : "Nastavit čas na příští týden",
    "Message link copied to clipboard" : "Odkaz na zprávu zkopírován do schránky",
    "Conversation link copied to clipboard" : "Odkaz na konverzaci zkopírován do schránky",
    "The link could not be copied" : "Odkaz se nepodařilo zkopírovat",
    "Error while parsing a PROPFIND error" : "Chyba při zpracovávání PROPFIND chyby",
    "Sending signaling message has failed" : "Odeslání signálové zprávy se nezdařilo",
    "Lost connection to signaling server. Trying to reconnect." : "Ztraceno spojení se signalizačním serverem. Probíhá pokus o opětovné navázání spojení.",
    "Lost connection to signaling server." : "Ztraceno spojení se signalizačním serverem",
    "Connecting is taking longer than expected …" : "Připojování trvá déle než očekáváno …",
    "Failed to connect. Retrying …" : "Nepodařilo se připojit. Zkouší se znovu …",
    "Failed to connect. The signaling server may be set up incorrectly" : "Nepodařilo se připojit. Je možné, že signalizační server není správně nastavený",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Nastavený signální server je třeba aktualizovat, aby byl kompatibilní s touto verzí Talk. Obraťte se na správu.",
    "Please restart the app." : "Restartujte aplikaci.",
    "Please reload the page." : "Načtěte stránku znovu.",
    "Please try to restart the app." : "Zkuste aplikaci ukončit a spustit znovu.",
    "Please try to reload the page." : "Zkuste stránku znovu načíst.",
    "Do not disturb" : "Nerušit",
    "Away" : "Pryč",
    "Microphone {number}" : "Mikrofon {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Reproduktor {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Zdá se, že mluvíte a přitom máte ztlumeno – zrušte ztlumení, aby vás ostatní slyšeli",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Nedaří se navázat spojení přinejmenším s jedním účastníkem. Pro váš scénář může být zapotřebí TURN server. Požádejte správce o nastavení nějakého podle {linkstart}této dokumentace{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Toto trvá déle než by mělo. Udělili už jste oprávnění pro přístup k médiím (nebo snad zamítli)? Pokud jsou oprávnění udělena, restartujte webový prohlížeč, protože zvuk a video se nedaří",
    "Access to microphone & camera is only possible with HTTPS" : "Přístup k mikrofonu a kameře je možný pouze přes HTTPS",
    "Please move your setup to HTTPS" : "Přesuňte svou instalaci na HTTPS",
    "Access to microphone & camera was denied" : "Přístup k mikrofonu a kameře byl odepřen",
    "WebRTC is not supported in your browser" : "Vámi používaný prohlížeč nepodporuje WebRTC",
    "Please use a different browser like Firefox or Chrome" : "Použijte jiný prohlížeč, jako třeba Firefox nebo Chrome",
    "Error while accessing microphone & camera" : "Chyba při přístupu k mikrofonu a kameře",
    "%s Talk on your mobile devices" : "%s Talk na vašich mobilních zařízeních",
    "Join conversations at any time, anywhere, on any device." : "Připojte se ke konverzaci kdykoli, kdekoli a z jakéhokoli zařízení.",
    "Android app" : "Aplikace pro Android",
    "iOS app" : "Aplikace pro iOS",
    "__language_name__" : "Čeština",
    "Webhook Demo" : "Ukázka webového háčku",
    "Call summary (%s)" : "Shrnutí hovoru (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Automat pošle po ukončení hovoru souhrnnou zprávu se seznamem všech účastníků a vytyčením úkolů",
    "Tasks" : "Úlohy",
    "Notes" : "Poznámky",
    "Reports" : "Výkazy",
    "Decisions" : "Rozhodnutí",
    "Agenda" : "Agenda",
    "Call summary" : "Shrnutí hovoru",
    "Call summary - {title}" : "Souhrn hovoru – {title}",
    "Talk conversation for event" : "Konverzace v Talk pro událost",
    "Client Push is installed, this improves the performance of desktop clients." : "Služba klient Push je nainstalovaná a bude zlepšovat výkon klientských aplikací pro počítač.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} není nainstalované – to může vést k problémům s výkonem při používání klientů pro počítač.",
    "Next meeting" : "Příští schůzka",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Naplánujte schůzku ze svého kalendáře. Aby se zde ukázala, je třeba konverzaci v Talk nastavit jako umístění",
    "Join conversations from remote Nextcloud servers" : "Připojte se do konverzací na vzdálených Nextcloud serverech",
    "Your default media state has been saved" : "Váš výchozí stav média byl uložen",
    "Set reminder for later today" : "Nastavit připomínku na později dnes",
    "Set reminder for tomorrow" : "Nastavit připomínku na zítra",
    "Set reminder for this weekend" : "Nastavit připomínku na tento víkend",
    "Set reminder for next week" : "Nastavit připomínku pro příští týden",
    "Generate summary" : "Vytvořit shrnutí",
    "Open poll • You voted already" : "Otevřená anketa ・ Už jste hlasovali",
    "Open poll • Click to vote" : "Otevřená anketa ・ Hlasujte kliknutím",
    "Poll • Ended" : "Anketa • Ukončeno",
    "Talk recording from {time} ({conversation})" : "Záznam z Talk z {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Výsledky ankety • %n hlas","Výsledky ankety • %n hlasy","Výsledky ankety • %n hlasů","Výsledky ankety • %n hlasy"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Otevřená anketa • %n hlas","Otevřená anketa • %n hlasy","Otevřená anketa • %n hlasů","Otevřená anketa • %n hlasy"],
    "Submit vote" : "Odeslat hlas",
    "Your privacy setting has been saved" : "Vaše nastavení soukromí byla uložena",
    "Your personal setting has been saved" : "Vaše osobní nastavení byla uložena",
    "Failed to save sounds setting" : "Nastavení zvuků se nepodařilo uložit",
    "Sounds setting saved" : "Nastavení zvuku uloženo",
    "Always shown if recording consent is required" : "Vždy zobrazováno, pokud je zapotřebí souhlas s nahráváním",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk bylo aktualizováno – nemůžete zahájit hovor nebo se k němu připojit.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Ke konverzaci jste se přidali z jiného okna nebo zařízení. Nextcloud zatím nepodporuje souběžná připojení a tak tato relace byla uzavřena.",
    "Nextcloud Talk was updated." : "Nextcloud Talk bylo aktualizováno.",
    "Nextcloud is in maintenance mode." : "Nextcloud se právě nachází v režimu údržby.",
    "Nextcloud Talk Federation was updated." : "Federovaní Nextcloud Talk bylo zaktualizováno.",
    "Enable live translation" : "Zapnout překlad v reálném čase",
    "I picked list style" : "Vybral/a jsem styl seznamu",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Hej! Používáte Talk ve stylu seznamu nebo bublin zpráv?"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
